FACILITY_CONTROL: int

def MAKE_SCODE(sev: int, fac: int, code: int) -> int: ...
def STD_CTL_SCODE(n: int) -> int: ...

CTL_E_ILLEGALFUNCTIONCALL: int
CTL_E_OVERFLOW: int
CTL_E_OUTOFMEMORY: int
CTL_E_DIVISIONBYZERO: int
CTL_E_OUTOFSTRINGSPACE: int
CTL_E_OUTOFSTACKSPACE: int
CTL_E_BADFILENAMEORNUMBER: int
CTL_E_FILENOTFOUND: int
CTL_E_BADFILEMODE: int
CTL_E_FILEALREADYOPEN: int
CTL_E_DEVICEIOERROR: int
CTL_E_FILEALREADYEXISTS: int
CTL_E_BADRECORDLENGTH: int
CTL_E_DISKFULL: int
CTL_E_BADRECORDNUMBER: int
CTL_E_BADFILENAME: int
CTL_E_TOOMANYFILES: int
CTL_E_DEVICEUNAVAILABLE: int
CTL_E_PERMISSIONDENIED: int
CTL_E_DISKNOTREADY: int
CTL_E_PATHFILEACCESSERROR: int
CTL_E_PATHNOTFOUND: int
CTL_E_INVALIDPATTERNSTRING: int
CTL_E_INVALIDUSEOFNULL: int
CTL_E_INVALIDFILEFORMAT: int
CTL_E_INVALIDPROPERTYVALUE: int
CTL_E_INVALIDPROPERTYARRAYINDEX: int
CTL_E_SETNOTSUPPORTEDATRUNTIME: int
CTL_E_SETNOTSUPPORTED: int
CTL_E_NEEDPROPERTYARRAYINDEX: int
CTL_E_SETNOTPERMITTED: int
CTL_E_GETNOTSUPPORTEDATRUNTIME: int
CTL_E_GETNOTSUPPORTED: int
CTL_E_PROPERTYNOTFOUND: int
CTL_E_INVALIDCLIPBOARDFORMAT: int
CTL_E_INVALIDPICTURE: int
CTL_E_PRINTERERROR: int
CTL_E_CANTSAVEFILETOTEMP: int
CTL_E_SEARCHTEXTNOTFOUND: int
CTL_E_REPLACEMENTSTOOLONG: int
CONNECT_E_FIRST: int
CONNECT_E_LAST: int
CONNECT_S_FIRST: int
CONNECT_S_LAST: int
CONNECT_E_NOCONNECTION: int
CONNECT_E_ADVISELIMIT: int
CONNECT_E_CANNOTCONNECT: int
CONNECT_E_OVERRIDDEN: int
CLASS_E_NOTLICENSED: int



from _typeshed import Incomplete, ReadableBuffer, WriteableBuffer
from collections.abc import Callable
from typing import TypeVar
from typing_extensions import Literal

import _win32typing
from win32.lib.pywintypes import error as error

_T = TypeVar("_T")

def EnumFontFamilies(hdc: int, Family: str, EnumFontFamProc, Param): ...
def set_logger(logger) -> None: ...
def LOGFONT() -> _win32typing.PyLOGFONT: ...
def CreateFontIndirect(lplf: _win32typing.PyLOGFONT): ...
def GetObject(handle: int): ...
def GetObjectType(h: int): ...
def PyGetMemory(__addr: int, __len: int): ...
def PyGetString(addr, _len=...) -> str: ...
def PySetString(addr, String, maxLen): ...
def PySetMemory(addr, String): ...
def PyGetArraySignedLong(array, index): ...
def PyGetBufferAddressAndLen(obj): ...
def FlashWindow(hwnd: int, bInvert): ...
def FlashWindowEx(hwnd: int, dwFlags, uCount, dwTimeout): ...
def GetWindowLong(hwnd: int, index): ...
def GetClassLong(hwnd: int, index): ...
def SetWindowLong(hwnd: int, index, value): ...
def CallWindowProc(wndproc, hwnd: int, msg, wparam, lparam): ...
def SendMessage(
    __hwnd: int | None, __message: int, __wparam: int | None = ..., __lparam: ReadableBuffer | float | None = ...
) -> int: ...
def SendMessageTimeout(
    __hwnd: int,
    __message: int,
    __wparam: ReadableBuffer | float | None,
    __lparam: ReadableBuffer | float | None,
    __flags: int,
    __timeout: int,
) -> tuple[int, int]: ...
def PostMessage(
    __hwnd: int | None, __message: int, __wparam: int | None = ..., __lparam: ReadableBuffer | float | None = ...
) -> None: ...
def PostThreadMessage(threadId, message, wparam, lparam) -> None: ...
def ReplyMessage(result): ...
def RegisterWindowMessage(name: str): ...
def DefWindowProc(
    hwnd: int | None, message: int, wparam: ReadableBuffer | float | None, lparam: ReadableBuffer | float | None
) -> int: ...
def EnumWindows(__callback: Callable[[int, _T], object], __extra: _T) -> None: ...
def EnumThreadWindows(dwThreadId, __callback: Callable[[int, _T], object], __extra: _T) -> None: ...
def EnumChildWindows(__hwnd: int | None, __callback: Callable[[int, _T], object], __extra: _T) -> None: ...
def DialogBox(hInstance: int, TemplateName: _win32typing.PyResourceId, hWndParent: int, DialogFunc, InitParam: int = ...): ...
def DialogBoxParam(): ...
def DialogBoxIndirect(
    hInstance: int, controllist: _win32typing.PyDialogTemplate, hWndParent: int, DialogFunc, InitParam: int = ...
): ...
def DialogBoxIndirectParam(): ...
def CreateDialogIndirect(
    hInstance: int, controllist: _win32typing.PyDialogTemplate, hWndParent: int, DialogFunc, InitParam: int = ...
): ...
def EndDialog(hwnd: int, result) -> None: ...
def GetDlgItem(hDlg: int, IDDlgItem): ...
def GetDlgItemInt(hDlg: int, IDDlgItem, Signed) -> None: ...
def SetDlgItemInt(hDlg: int, IDDlgItem, Value, Signed) -> None: ...
def GetDlgCtrlID(hwnd: int): ...
def GetDlgItemText(hDlg: int, IDDlgItem) -> str: ...
def SetDlgItemText(hDlg: int, IDDlgItem, String) -> None: ...
def GetNextDlgTabItem(hDlg, hCtl, bPrevious): ...
def GetNextDlgGroupItem(hDlg, hCtl, bPrevious): ...
def SetWindowText() -> None: ...
def GetWindowText(hwnd: int) -> str: ...
def InitCommonControls() -> None: ...
def InitCommonControlsEx(flag) -> None: ...
def LoadCursor(hinstance, resid): ...
def SetCursor(hcursor): ...
def GetCursor(): ...
def GetCursorInfo() -> tuple[int, int, int, int]: ...
def CreateAcceleratorTable(accels: tuple[tuple[Incomplete, Incomplete, Incomplete], ...]): ...
def LoadMenu(hinstance, resource_id: str): ...
def DestroyMenu() -> None: ...
def SetMenu(hwnd: int, hmenu) -> None: ...
def GetMenu(__hwnd: int) -> int: ...
def LoadIcon(__hinstance: int, __resource_id_or_name: str | int) -> _win32typing.PyWNDCLASS: ...
def CopyIcon(hicon): ...
def DrawIcon(hDC, X, Y, hicon) -> None: ...
def DrawIconEx(
    hDC, xLeft, yTop, hIcon, cxWidth, cyWidth, istepIfAniCur, hbrFlickerFreeDraw: _win32typing.PyGdiHANDLE, diFlags
) -> None: ...
def CreateIconIndirect(iconinfo: _win32typing.PyICONINFO): ...
def CreateIconFromResource(bits: str, fIcon, ver: int = ...) -> int: ...
def LoadImage(
    __hinst: int, __name: str, __type: int, __cxDesired: int, __cyDesired: int, __fuLoad: int
) -> _win32typing.PyGdiHANDLE: ...
def DeleteObject(handle: _win32typing.PyGdiHANDLE) -> None: ...
def BitBlt(hdcDest, x, y, width, height, hdcSrc, nXSrc, nYSrc, dwRop) -> None: ...
def StretchBlt(hdcDest, x, y, width, height, hdcSrc, nXSrc, nYSrc, nWidthSrc, nHeightSrc, dwRop) -> None: ...
def PatBlt(hdc: int, XLeft, YLeft, Width, Height, Rop) -> None: ...
def SetStretchBltMode(hdc: int, StretchMode): ...
def GetStretchBltMode(hdc: int): ...
def TransparentBlt(
    Dest: int, XOriginDest, YOriginDest, WidthDest, HeightDest, Src: int, XOriginSrc, YOriginSrc, WidthSrc, HeightSrc, Transparent
) -> None: ...
def MaskBlt(
    Dest: int, XDest, YDest, Width, Height, Src: int, XSrc, YSrc, Mask: _win32typing.PyGdiHANDLE, xMask, yMask, Rop
) -> None: ...
def AlphaBlend(
    Dest: int,
    XOriginDest,
    YOriginDest,
    WidthDest,
    HeightDest,
    Src: int,
    XOriginSrc,
    YOriginSrc,
    WidthSrc,
    HeightSrc,
    blendFunction: _win32typing.PyBLENDFUNCTION,
) -> None: ...
def MessageBox(parent, text: str, caption: str, flags): ...
def MessageBeep(_type) -> None: ...
def CreateWindow(
    __className: str | _win32typing.PyResourceId,
    __windowTitle: str | None,
    __style: int,
    __x: int,
    __y: int,
    __width: int,
    __height: int,
    __parent: int,
    __menu: int,
    __hinstance: int,
    __reserved: Incomplete | None,
) -> int: ...
def DestroyWindow(_hwnd: int) -> None: ...
def EnableWindow(hWnd: int, bEnable): ...
def FindWindow(__ClassName: _win32typing.PyResourceId | str | None, __WindowName: str | None) -> int: ...
def FindWindowEx(
    __Parent: int | None, __ChildAfter: int | None, __ClassName: _win32typing.PyResourceId | str | None, __WindowName: str | None
) -> int: ...
def DragAcceptFiles(hwnd: int, fAccept) -> None: ...
def DragDetect(hwnd: int, point: tuple[Incomplete, Incomplete]) -> None: ...
def SetDoubleClickTime(newVal) -> None: ...
def GetDoubleClickTime(): ...
def HideCaret(hWnd: int) -> None: ...
def SetCaretPos(x, y) -> None: ...
def GetCaretPos() -> tuple[Incomplete, Incomplete]: ...
def ShowCaret(hWnd: int) -> None: ...
def ShowWindow(__hWnd: int | None, __cmdShow: int) -> int: ...
def IsWindowVisible(__hwnd: int | None) -> int: ...
def IsWindowEnabled(__hwnd: int | None) -> int: ...
def SetFocus(hwnd: int) -> None: ...
def GetFocus() -> None: ...
def UpdateWindow(__hwnd: int) -> None: ...
def BringWindowToTop(hwnd: int) -> None: ...
def SetActiveWindow(hwnd: int): ...
def GetActiveWindow(): ...
def SetForegroundWindow(__hwnd: int) -> None: ...
def GetForegroundWindow() -> int: ...
def GetClientRect(hwnd: int) -> tuple[int, int, int, int]: ...
def GetDC(hwnd: int): ...
def SaveDC(hdc: int): ...
def RestoreDC(hdc: int, SavedDC) -> None: ...
def DeleteDC(hdc) -> None: ...
def CreateCompatibleDC(dc): ...
def CreateCompatibleBitmap(hdc, width, height) -> _win32typing.PyGdiHANDLE: ...
def CreateBitmap(width, height, cPlanes, cBitsPerPixel, bitmap_bits) -> _win32typing.PyGdiHANDLE: ...
def SelectObject(hdc, _object): ...
def GetCurrentObject(hdc: int, ObjectType) -> int: ...
def GetWindowRect(hwnd: int) -> tuple[int, int, int, int]: ...
def GetStockObject(Object) -> int: ...
def PostQuitMessage(__rc: int) -> None: ...
def WaitMessage() -> None: ...
def SetWindowPos(__hWnd: int, __InsertAfter: int | None, __X: int, __Y: int, __cx: int, __cy: int, __Flags: int) -> None: ...
def GetWindowPlacement(__hwnd: int) -> tuple[int, int, tuple[int, int], tuple[int, int], tuple[int, int, int, int]]: ...
def SetWindowPlacement(hWnd: int, placement) -> None: ...
def RegisterClass(__wndClass: _win32typing.PyWNDCLASS) -> _win32typing.PyResourceId: ...
def UnregisterClass(__atom: _win32typing.PyResourceId, __hinst: int) -> None: ...
def PumpMessages() -> None: ...
def PumpWaitingMessages(__firstMessage: int = ..., __lastMessage: int = ...) -> int: ...
def GetMessage(hwnd: int, _min, _max): ...
def TranslateMessage(msg): ...
def DispatchMessage(msg): ...
def TranslateAccelerator(hwnd: int, haccel, msg): ...
def PeekMessage(hwnd: int, filterMin, filterMax, removalOptions): ...
def Shell_NotifyIcon(__Message: int, __nid: _win32typing.PyNOTIFYICONDATA) -> None: ...
def GetSystemMenu(hwnd: int, bRevert): ...
def DrawMenuBar(hwnd: int) -> None: ...
def MoveWindow(__hwnd: int, __x: int, __y: int, __width: int, __height: int, __bRepaint: bool) -> None: ...
def CloseWindow() -> None: ...
def DeleteMenu(hmenu, position, flags) -> None: ...
def RemoveMenu(hmenu, position, flags) -> None: ...
def CreateMenu(): ...
def CreatePopupMenu(): ...
def TrackPopupMenu(hmenu, flags, x, y, reserved, hwnd: int, prcRect: _win32typing.PyRECT): ...
def CommDlgExtendedError(): ...
def ExtractIcon(hinstance, moduleName: str, index): ...
def ExtractIconEx(moduleName: str, index, numIcons: int = ...): ...
def DestroyIcon(hicon) -> None: ...
def GetIconInfo(hicon: int) -> _win32typing.PyICONINFO: ...
def ScreenToClient(hWnd: int, Point: tuple[Incomplete, Incomplete]) -> tuple[Incomplete, Incomplete]: ...
def ClientToScreen(hWnd: int, Point: tuple[Incomplete, Incomplete]) -> tuple[Incomplete, Incomplete]: ...
def PaintDesktop(hdc: int) -> None: ...
def RedrawWindow(hWnd: int, rcUpdate: tuple[int, int, int, int], hrgnUpdate: _win32typing.PyGdiHANDLE, flags) -> None: ...
def GetTextExtentPoint32(hdc: int, _str: str) -> tuple[Incomplete, Incomplete]: ...
def GetTextMetrics(): ...
def GetTextCharacterExtra(hdc: int): ...
def SetTextCharacterExtra(hdc: int, CharExtra): ...
def GetTextAlign(hdc: int): ...
def SetTextAlign(hdc: int, Mode): ...
def GetTextFace(hdc: int) -> str: ...
def GetMapMode(hdc: int): ...
def SetMapMode(hdc: int, MapMode): ...
def GetGraphicsMode(hdc: int): ...
def SetGraphicsMode(hdc: int, Mode): ...
def GetLayout(hdc: int): ...
def SetLayout(hdc: int, Layout): ...
def GetPolyFillMode(hdc: int): ...
def SetPolyFillMode(hdc: int, PolyFillMode): ...
def GetWorldTransform(hdc: int) -> _win32typing.PyXFORM: ...
def SetWorldTransform(hdc: int, Xform: _win32typing.PyXFORM) -> None: ...
def ModifyWorldTransform(hdc: int, Xform: _win32typing.PyXFORM, Mode) -> None: ...
def CombineTransform(xform1: _win32typing.PyXFORM, xform2: _win32typing.PyXFORM) -> _win32typing.PyXFORM: ...
def GetWindowOrgEx(hdc: int) -> tuple[Incomplete, Incomplete]: ...
def SetWindowOrgEx(hdc: int, X, Y) -> tuple[Incomplete, Incomplete]: ...
def GetViewportOrgEx(hdc: int) -> tuple[Incomplete, Incomplete]: ...
def SetViewportOrgEx(hdc: int, X, Y) -> tuple[Incomplete, Incomplete]: ...
def GetWindowExtEx(hdc: int) -> tuple[Incomplete, Incomplete]: ...
def SetWindowExtEx(hdc: int, XExtent, YExtent) -> tuple[Incomplete, Incomplete]: ...
def GetViewportExtEx(hdc: int) -> tuple[Incomplete, Incomplete]: ...
def SetViewportExtEx(hdc: int, XExtent, YExtent) -> tuple[Incomplete, Incomplete]: ...
def GradientFill(hdc, Vertex: tuple[_win32typing.PyTRIVERTEX, ...], Mesh, Mode) -> None: ...
def GetOpenFileName(OPENFILENAME: str): ...
def InsertMenuItem(hMenu, uItem, fByPosition, menuItem) -> None: ...
def SetMenuItemInfo(hMenu, uItem, fByPosition, menuItem) -> None: ...
def GetMenuItemInfo(__hMenu: int, __uItem: int, __fByPosition: bool, __menuItem: ReadableBuffer) -> None: ...
def GetMenuItemCount(__hMenu: int | None) -> int: ...

# Actually returns a list of int|tuple, but lists don't support positional types
def GetMenuItemRect(__hWnd: int | None, __hMenu: int | None, __uItem: int) -> tuple[int, tuple[int, int, int, int]]: ...
def GetMenuState(hMenu, uID, flags): ...
def SetMenuDefaultItem(hMenu, uItem, fByPos) -> None: ...
def GetMenuDefaultItem(hMenu, fByPos, flags): ...
def AppendMenu() -> None: ...
def InsertMenu() -> None: ...
def EnableMenuItem() -> None: ...
def CheckMenuItem(): ...
def GetSubMenu(hMenu, nPos): ...
def ModifyMenu(hMnu, uPosition, uFlags, uIDNewItem, newItem: str) -> None: ...
def GetMenuItemID(hMenu, nPos): ...
def SetMenuItemBitmaps(
    hMenu, uPosition, uFlags, hBitmapUnchecked: _win32typing.PyGdiHANDLE, hBitmapChecked: _win32typing.PyGdiHANDLE
) -> None: ...
def CheckMenuRadioItem(hMenu, idFirst, idLast, idCheck, uFlags) -> None: ...
def SetMenuInfo(hmenu, info) -> None: ...
def GetMenuInfo(__hmenu: int, __info: WriteableBuffer) -> None: ...
def DrawFocusRect(hDC: int, rc: tuple[int, int, int, int]) -> None: ...
def DrawText(hDC: int, String, nCount, Rect: _win32typing.PyRECT, Format) -> tuple[Incomplete, _win32typing.PyRECT]: ...
def LineTo(hdc: int, XEnd, YEnd) -> None: ...
def Ellipse(hdc: int, LeftRect, TopRect, RightRect, BottomRect) -> None: ...
def Pie(hdc: int, LeftRect, TopRect, RightRect, BottomRect, XRadial1, YRadial1, XRadial2, YRadial2) -> None: ...
def Arc(hdc: int, LeftRect, TopRect, RightRect, BottomRect, XRadial1, YRadial1, XRadial2, YRadial2) -> None: ...
def ArcTo(hdc: int, LeftRect, TopRect, RightRect, BottomRect, XRadial1, YRadial1, XRadial2, YRadial2) -> None: ...
def AngleArc(hdc: int, Y, Y1, Radius, StartAngle: float, SweepAngle: float) -> None: ...
def Chord(hdc: int, LeftRect, TopRect, RightRect, BottomRect, XRadial1, YRadial1, XRadial2, YRadial2) -> None: ...
def ExtFloodFill(arg: int, XStart, YStart, Color, FillType) -> None: ...
def SetPixel(hdc: int, X, Y, Color): ...
def GetPixel(hdc: int, XPos, YPos): ...
def GetROP2(hdc: int): ...
def SetROP2(hdc: int, DrawMode): ...
def SetPixelV(hdc: int, X, Y, Color) -> None: ...
def MoveToEx(hdc: int, X, Y) -> tuple[Incomplete, Incomplete]: ...
def GetCurrentPositionEx(hdc: int) -> tuple[Incomplete, Incomplete]: ...
def GetArcDirection(hdc: int): ...
def SetArcDirection(hdc: int, ArcDirection): ...
def Polygon(hdc: int, Points: list[tuple[Incomplete, Incomplete]]) -> None: ...
def Polyline(hdc: int, Points: list[tuple[Incomplete, Incomplete]]) -> None: ...
def PolylineTo(hdc: int, Points: list[tuple[Incomplete, Incomplete]]) -> None: ...
def PolyBezier(hdc: int, Points: list[tuple[Incomplete, Incomplete]]) -> None: ...
def PolyBezierTo(hdc: int, Points: list[tuple[Incomplete, Incomplete]]) -> None: ...
def PlgBlt(
    Dest: int,
    Point,
    Src: int,
    XSrc,
    YSrc,
    Width,
    Height,
    Mask: _win32typing.PyGdiHANDLE | None = ...,
    xMask: int = ...,
    yMask: int = ...,
) -> None: ...
def CreatePolygonRgn(Points: list[tuple[Incomplete, Incomplete]], PolyFillMode) -> _win32typing.PyGdiHANDLE: ...
def ExtTextOut(
    hdc: int, _int, _int1, _int2, rect: _win32typing.PyRECT, string, _tuple: tuple[tuple[Incomplete, Incomplete], ...]
): ...
def GetTextColor(hdc): ...
def SetTextColor(hdc, color): ...
def GetBkMode(hdc: int): ...
def SetBkMode(hdc: int, BkMode): ...
def GetBkColor(hdc: int): ...
def SetBkColor(hdc: int, color): ...
def DrawEdge(hdc: int, rc: _win32typing.PyRECT, edge, Flags) -> _win32typing.PyRECT: ...
def FillRect(hDC: int, rc: _win32typing.PyRECT, hbr: _win32typing.PyGdiHANDLE) -> None: ...
def FillRgn(hdc: int, hrgn: _win32typing.PyGdiHANDLE, hbr: _win32typing.PyGdiHANDLE) -> None: ...
def PaintRgn(hdc: int, hrgn: _win32typing.PyGdiHANDLE) -> None: ...
def FrameRgn(hdc: int, hrgn, hbr, Width, Height) -> None: ...
def InvertRgn(hdc: int, hrgn) -> None: ...
def EqualRgn(SrcRgn1, SrcRgn2): ...
def PtInRegion(hrgn, X, Y): ...
def PtInRect(rect: tuple[int, int, int, int], point: tuple[Incomplete, Incomplete]): ...
def RectInRegion(hrgn, rc: _win32typing.PyRECT): ...
def SetRectRgn(hrgn, LeftRect, TopRect, RightRect, BottomRect) -> None: ...
def CombineRgn(Dest, Src1, Src2, CombineMode): ...
def DrawAnimatedRects(hwnd: int, idAni, minCoords: _win32typing.PyRECT, restCoords: _win32typing.PyRECT) -> None: ...
def CreateSolidBrush(Color) -> _win32typing.PyGdiHANDLE: ...
def CreatePatternBrush(hbmp: _win32typing.PyGdiHANDLE) -> _win32typing.PyGdiHANDLE: ...
def CreateHatchBrush(Style, clrref) -> _win32typing.PyGdiHANDLE: ...
def CreatePen(PenStyle, Width, Color) -> _win32typing.PyGdiHANDLE: ...
def GetSysColor(Index): ...
def GetSysColorBrush(Index) -> _win32typing.PyGdiHANDLE: ...
def InvalidateRect(hWnd: int, Rect: _win32typing.PyRECT, Erase) -> None: ...
def FrameRect(hDC: int, rc: _win32typing.PyRECT, hbr: _win32typing.PyGdiHANDLE) -> None: ...
def InvertRect(hDC: int, rc: _win32typing.PyRECT) -> None: ...
def WindowFromDC(hDC: int) -> int: ...
def GetUpdateRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE, Erase): ...
def GetWindowRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE): ...
def SetWindowRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE, Redraw) -> None: ...
def ValidateRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE) -> None: ...
def InvalidateRgn(hWnd: int, hRgn: _win32typing.PyGdiHANDLE, Erase) -> None: ...
def GetRgnBox(hrgn: _win32typing.PyGdiHANDLE) -> tuple[Incomplete, _win32typing.PyRECT]: ...
def OffsetRgn(hrgn: _win32typing.PyGdiHANDLE, XOffset, YOffset): ...
def Rectangle(hdc: int, LeftRect, TopRect, RightRect, BottomRect) -> None: ...
def RoundRect(hdc: int, LeftRect, TopRect, RightRect, BottomRect, Width, Height) -> None: ...
def BeginPaint() -> tuple[Incomplete, Incomplete]: ...
def EndPaint(hwnd: int, ps) -> None: ...
def BeginPath(hdc: int) -> None: ...
def EndPath(hdc: int) -> None: ...
def AbortPath(hdc: int) -> None: ...
def CloseFigure(hdc: int) -> None: ...
def FlattenPath(hdc: int) -> None: ...
def FillPath(hdc: int) -> None: ...
def WidenPath(hdc: int) -> None: ...
def StrokePath(hdc: int) -> None: ...
def StrokeAndFillPath(hdc: int) -> None: ...
def GetMiterLimit(hdc: int) -> float: ...
def SetMiterLimit(hdc: int, NewLimit: float) -> float: ...
def PathToRegion(hdc: int) -> _win32typing.PyGdiHANDLE: ...
def GetPath(hdc: int) -> tuple[Incomplete, Incomplete]: ...
def CreateRoundRectRgn(LeftRect, TopRect, RightRect, BottomRect, WidthEllipse, HeightEllipse): ...
def CreateRectRgnIndirect(rc: _win32typing.PyRECT): ...
def CreateEllipticRgnIndirect(rc: _win32typing.PyRECT): ...
def CreateWindowEx(
    dwExStyle, className: str, windowTitle: str, style, x, y, width, height, parent, menu, hinstance, reserved
): ...
def GetParent(child: int) -> int: ...
def SetParent(__child: int, __child1: int | None | _win32typing.PyHANDLE) -> int: ...
def GetCursorPos() -> tuple[Incomplete, Incomplete]: ...
def GetDesktopWindow(): ...
def GetWindow(__hWnd: int, __uCmd: int) -> int: ...
def GetWindowDC(hWnd: int) -> int: ...
def IsIconic(__hWnd: int) -> int: ...
def IsWindow(__hWnd: int) -> int: ...
def IsChild(__hWndParent: int, hWnd: int) -> int: ...
def ReleaseCapture() -> None: ...
def GetCapture(): ...
def SetCapture() -> None: ...
def ReleaseDC(hWnd: int, hDC): ...
def CreateCaret(hWnd: int, hBitmap: _win32typing.PyGdiHANDLE, nWidth, nHeight) -> None: ...
def DestroyCaret() -> None: ...
def ScrollWindowEx(
    hWnd: int, dx, dy, rcScroll: _win32typing.PyRECT, rcClip: _win32typing.PyRECT, hrgnUpdate, flags
) -> tuple[Incomplete, _win32typing.PyRECT]: ...
def SetScrollInfo(hwnd: int, nBar, scollInfo: _win32typing.PySCROLLINFO, bRedraw=...) -> None: ...
def GetScrollInfo(hwnd: int, nBar, mask) -> _win32typing.PySCROLLINFO: ...
def GetClassName(hwnd: int) -> str: ...
def WindowFromPoint(point: tuple[int, int]) -> int: ...
def ChildWindowFromPoint(hwndParent: int, point: tuple[Incomplete, Incomplete]): ...
def CreateDC(Driver: str, Device: str, InitData: _win32typing.PyDEVMODE): ...
def GetSaveFileNameW(
    hwndOwner: int | None = ...,
    hInstance: int | None = ...,
    Filter: Incomplete | None = ...,
    CustomFilter: Incomplete | None = ...,
    FilterIndex: int = ...,
    File: Incomplete | None = ...,
    MaxFile: int = ...,
    InitialDir: Incomplete | None = ...,
    Title: Incomplete | None = ...,
    Flags: int = ...,
    DefExt: Incomplete | None = ...,
    TemplateName: _win32typing.PyResourceId | None = ...,
) -> tuple[Incomplete, Incomplete, Incomplete]: ...
def GetOpenFileNameW(
    hwndOwner: int | None = ...,
    hInstance: int | None = ...,
    Filter: Incomplete | None = ...,
    CustomFilter: Incomplete | None = ...,
    FilterIndex: int = ...,
    File: Incomplete | None = ...,
    MaxFile: int = ...,
    InitialDir: Incomplete | None = ...,
    Title: Incomplete | None = ...,
    Flags: int = ...,
    DefExt: Incomplete | None = ...,
    TemplateName: _win32typing.PyResourceId | None = ...,
) -> tuple[Incomplete, Incomplete, Incomplete]: ...
def SystemParametersInfo(Action, Param: Incomplete | None = ..., WinIni: int = ...) -> None: ...
def SetLayeredWindowAttributes(hwnd: int, Key, Alpha, Flags) -> None: ...
def GetLayeredWindowAttributes(hwnd: int) -> tuple[Incomplete, Incomplete, Incomplete]: ...
def UpdateLayeredWindow(
    hwnd: int,
    arg: tuple[int, int, int, int],
    hdcDst: int | None = ...,
    ptDst: tuple[Incomplete, Incomplete] | None = ...,
    size: tuple[Incomplete, Incomplete] | None = ...,
    hdcSrc: Incomplete | None = ...,
    ptSrc: tuple[Incomplete, Incomplete] | None = ...,
    Key: int = ...,
    Flags: int = ...,
) -> None: ...
def AnimateWindow(hwnd: int, Time, Flags) -> None: ...
def CreateBrushIndirect(lb: _win32typing.PyLOGBRUSH) -> _win32typing.PyGdiHANDLE: ...
def ExtCreatePen(PenStyle, Width, lb: _win32typing.PyLOGBRUSH, Style: tuple[Incomplete, ...] | None = ...) -> int: ...
def DrawTextW(hDC: int, String: str, Count, Rect: _win32typing.PyRECT, Format) -> tuple[Incomplete, _win32typing.PyRECT]: ...
def EnumPropsEx(hWnd: int, EnumFunc, Param) -> None: ...
def RegisterDeviceNotification(handle: int, _filter, flags) -> _win32typing.PyHDEVNOTIFY: ...
def UnregisterDeviceNotification() -> None: ...
def RegisterHotKey(hWnd: int, _id, Modifiers, vk) -> None: ...
def GetAncestor(__hwnd: int, __gaFlags: int) -> int: ...
def GetTopWindow(__hWnd: int | None) -> int: ...
def ChildWindowFromPointEx(*args, **kwargs): ...  # incomplete
def CreateDialogIndirectParam(*args, **kwargs): ...  # incomplete
def DestroyAcceleratorTable(*args, **kwargs): ...  # incomplete
def Edit_GetLine(*args, **kwargs): ...  # incomplete
def GetModuleHandle(__lpModuleName: str | None) -> int: ...
def GetWindowTextLength(*args, **kwargs): ...  # incomplete
def HIWORD(*args, **kwargs): ...  # incomplete
def ImageList_Add(*args, **kwargs): ...  # incomplete
def ImageList_Create(*args, **kwargs): ...  # incomplete
def ImageList_Destroy(*args, **kwargs): ...  # incomplete
def ImageList_Draw(*args, **kwargs): ...  # incomplete
def ImageList_DrawEx(*args, **kwargs): ...  # incomplete
def ImageList_GetIcon(*args, **kwargs): ...  # incomplete
def ImageList_GetImageCount(*args, **kwargs): ...  # incomplete
def ImageList_LoadBitmap(*args, **kwargs): ...  # incomplete
def ImageList_LoadImage(*args, **kwargs): ...  # incomplete
def ImageList_Remove(*args, **kwargs): ...  # incomplete
def ImageList_Replace(*args, **kwargs): ...  # incomplete
def ImageList_ReplaceIcon(*args, **kwargs): ...  # incomplete
def ImageList_SetBkColor(*args, **kwargs): ...  # incomplete
def ImageList_SetOverlayImage(*args, **kwargs): ...  # incomplete
def LOWORD(*args, **kwargs): ...  # incomplete
def ListView_SortItems(*args, **kwargs): ...  # incomplete
def ListView_SortItemsEx(*args, **kwargs): ...  # incomplete
def ValidateRect(*args, **kwargs): ...  # incomplete
def WNDCLASS() -> _win32typing.PyWNDCLASS: ...
def lpstr(*args, **kwargs): ...  # incomplete

CLR_NONE: int
ILC_COLOR: int
ILC_COLOR16: int
ILC_COLOR24: int
ILC_COLOR32: int
ILC_COLOR4: int
ILC_COLOR8: int
ILC_COLORDDB: int
ILC_MASK: int
ILD_BLEND: int
ILD_BLEND25: int
ILD_BLEND50: int
ILD_FOCUS: int
ILD_MASK: int
ILD_NORMAL: int
ILD_SELECTED: int
ILD_TRANSPARENT: int
IMAGE_BITMAP: int
IMAGE_CURSOR: int
IMAGE_ICON: int
LR_CREATEDIBSECTION: int
LR_DEFAULTCOLOR: int
LR_DEFAULTSIZE: int
LR_LOADFROMFILE: int
LR_LOADMAP3DCOLORS: int
LR_LOADTRANSPARENT: int
LR_MONOCHROME: int
LR_SHARED: int
LR_VGACOLOR: int
NIF_ICON: int
NIF_INFO: int
NIF_MESSAGE: int
NIF_STATE: int
NIF_TIP: int
NIIF_ERROR: int
NIIF_ICON_MASK: int
NIIF_INFO: int
NIIF_NONE: int
NIIF_NOSOUND: int
NIIF_WARNING: int
NIM_ADD: int
NIM_DELETE: int
NIM_MODIFY: int
NIM_SETVERSION: int
TPM_BOTTOMALIGN: int
TPM_CENTERALIGN: int
TPM_LEFTALIGN: int
TPM_LEFTBUTTON: int
TPM_NONOTIFY: int
TPM_RETURNCMD: int
TPM_RIGHTALIGN: int
TPM_RIGHTBUTTON: int
TPM_TOPALIGN: int
TPM_VCENTERALIGN: int
UNICODE: Literal[True]
dllhandle: int



from _typeshed import Incomplete

from win32comext.mapi.mapitags import (
    PROP_TAG as PROP_TAG,
    PT_APPTIME as PT_APPTIME,
    PT_BINARY as PT_BINARY,
    PT_BOOLEAN as PT_BOOLEAN,
    PT_CLSID as PT_CLSID,
    PT_CURRENCY as PT_CURRENCY,
    PT_DOUBLE as PT_DOUBLE,
    PT_ERROR as PT_ERROR,
    PT_FLOAT as PT_FLOAT,
    PT_I2 as PT_I2,
    PT_I4 as PT_I4,
    PT_I8 as PT_I8,
    PT_LONG as PT_LONG,
    PT_LONGLONG as PT_LONGLONG,
    PT_MV_APPTIME as PT_MV_APPTIME,
    PT_MV_BINARY as PT_MV_BINARY,
    PT_MV_CLSID as PT_MV_CLSID,
    PT_MV_CURRENCY as PT_MV_CURRENCY,
    PT_MV_DOUBLE as PT_MV_DOUBLE,
    PT_MV_FLOAT as PT_MV_FLOAT,
    PT_MV_I2 as PT_MV_I2,
    PT_MV_I4 as PT_MV_I4,
    PT_MV_I8 as PT_MV_I8,
    PT_MV_LONG as PT_MV_LONG,
    PT_MV_LONGLONG as PT_MV_LONGLONG,
    PT_MV_R4 as PT_MV_R4,
    PT_MV_R8 as PT_MV_R8,
    PT_MV_SHORT as PT_MV_SHORT,
    PT_MV_STRING8 as PT_MV_STRING8,
    PT_MV_SYSTIME as PT_MV_SYSTIME,
    PT_MV_TSTRING as PT_MV_TSTRING,
    PT_MV_UNICODE as PT_MV_UNICODE,
    PT_NULL as PT_NULL,
    PT_OBJECT as PT_OBJECT,
    PT_R4 as PT_R4,
    PT_SHORT as PT_SHORT,
    PT_STRING8 as PT_STRING8,
    PT_SYSTIME as PT_SYSTIME,
    PT_TSTRING as PT_TSTRING,
    PT_UNICODE as PT_UNICODE,
    PT_UNSPECIFIED as PT_UNSPECIFIED,
)

AB_SHOW_PHANTOMS: int
AB_SHOW_OTHERS: int
EMS_AB_ADDRESS_LOOKUP: int
PR_EMS_AB_SERVER: Incomplete
PR_EMS_AB_SERVER_A: Incomplete
PR_EMS_AB_SERVER_W: Incomplete
PR_EMS_AB_CONTAINERID: Incomplete
PR_EMS_AB_DOS_ENTRYID: Incomplete
PR_EMS_AB_PARENT_ENTRYID: Incomplete
PR_EMS_AB_IS_MASTER: Incomplete
PR_EMS_AB_OBJECT_OID: Incomplete
PR_EMS_AB_HIERARCHY_PATH: Incomplete
PR_EMS_AB_HIERARCHY_PATH_A: Incomplete
PR_EMS_AB_HIERARCHY_PATH_W: Incomplete
PR_EMS_AB_CHILD_RDNS: Incomplete
MIN_EMS_AB_CONSTRUCTED_PROP_ID: int
PR_EMS_AB_OTHER_RECIPS: Incomplete
PR_EMS_AB_DISPLAY_NAME_PRINTABLE: Incomplete
PR_EMS_AB_DISPLAY_NAME_PRINTABLE_A: Incomplete
PR_EMS_AB_DISPLAY_NAME_PRINTABLE_W: Incomplete
PR_EMS_AB_ACCESS_CATEGORY: Incomplete
PR_EMS_AB_ACTIVATION_SCHEDULE: Incomplete
PR_EMS_AB_ACTIVATION_STYLE: Incomplete
PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE: Incomplete
PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE_MSDOS: Incomplete
PR_EMS_AB_ADDRESS_SYNTAX: Incomplete
PR_EMS_AB_ADDRESS_TYPE: Incomplete
PR_EMS_AB_ADDRESS_TYPE_A: Incomplete
PR_EMS_AB_ADDRESS_TYPE_W: Incomplete
PR_EMS_AB_ADMD: Incomplete
PR_EMS_AB_ADMD_A: Incomplete
PR_EMS_AB_ADMD_W: Incomplete
PR_EMS_AB_ADMIN_DESCRIPTION: Incomplete
PR_EMS_AB_ADMIN_DESCRIPTION_A: Incomplete
PR_EMS_AB_ADMIN_DESCRIPTION_W: Incomplete
PR_EMS_AB_ADMIN_DISPLAY_NAME: Incomplete
PR_EMS_AB_ADMIN_DISPLAY_NAME_A: Incomplete
PR_EMS_AB_ADMIN_DISPLAY_NAME_W: Incomplete
PR_EMS_AB_ADMIN_EXTENSION_DLL: Incomplete
PR_EMS_AB_ADMIN_EXTENSION_DLL_A: Incomplete
PR_EMS_AB_ADMIN_EXTENSION_DLL_W: Incomplete
PR_EMS_AB_ALIASED_OBJECT_NAME: Incomplete
PR_EMS_AB_ALIASED_OBJECT_NAME_A: Incomplete
PR_EMS_AB_ALIASED_OBJECT_NAME_W: Incomplete
PR_EMS_AB_ALIASED_OBJECT_NAME_O: Incomplete
PR_EMS_AB_ALIASED_OBJECT_NAME_T: Incomplete
PR_EMS_AB_ALT_RECIPIENT: Incomplete
PR_EMS_AB_ALT_RECIPIENT_A: Incomplete
PR_EMS_AB_ALT_RECIPIENT_W: Incomplete
PR_EMS_AB_ALT_RECIPIENT_O: Incomplete
PR_EMS_AB_ALT_RECIPIENT_T: Incomplete
PR_EMS_AB_ALT_RECIPIENT_BL: Incomplete
PR_EMS_AB_ALT_RECIPIENT_BL_A: Incomplete
PR_EMS_AB_ALT_RECIPIENT_BL_W: Incomplete
PR_EMS_AB_ALT_RECIPIENT_BL_O: Incomplete
PR_EMS_AB_ALT_RECIPIENT_BL_T: Incomplete
PR_EMS_AB_ANCESTOR_ID: Incomplete
PR_EMS_AB_ASSOC_NT_ACCOUNT: Incomplete
PR_EMS_AB_ASSOC_REMOTE_DXA: Incomplete
PR_EMS_AB_ASSOC_REMOTE_DXA_A: Incomplete
PR_EMS_AB_ASSOC_REMOTE_DXA_W: Incomplete
PR_EMS_AB_ASSOC_REMOTE_DXA_O: Incomplete
PR_EMS_AB_ASSOC_REMOTE_DXA_T: Incomplete
PR_EMS_AB_ASSOCIATION_LIFETIME: Incomplete
PR_EMS_AB_AUTH_ORIG_BL: Incomplete
PR_EMS_AB_AUTH_ORIG_BL_A: Incomplete
PR_EMS_AB_AUTH_ORIG_BL_W: Incomplete
PR_EMS_AB_AUTH_ORIG_BL_O: Incomplete
PR_EMS_AB_AUTH_ORIG_BL_T: Incomplete
PR_EMS_AB_AUTHORITY_REVOCATION_LIST: Incomplete
PR_EMS_AB_AUTHORIZED_DOMAIN: Incomplete
PR_EMS_AB_AUTHORIZED_DOMAIN_A: Incomplete
PR_EMS_AB_AUTHORIZED_DOMAIN_W: Incomplete
PR_EMS_AB_AUTHORIZED_PASSWORD: Incomplete
PR_EMS_AB_AUTHORIZED_USER: Incomplete
PR_EMS_AB_AUTHORIZED_USER_A: Incomplete
PR_EMS_AB_AUTHORIZED_USER_W: Incomplete
PR_EMS_AB_AUTOREPLY: Incomplete
PR_EMS_AB_AUTOREPLY_MESSAGE: Incomplete
PR_EMS_AB_AUTOREPLY_MESSAGE_A: Incomplete
PR_EMS_AB_AUTOREPLY_MESSAGE_W: Incomplete
PR_EMS_AB_AUTOREPLY_SUBJECT: Incomplete
PR_EMS_AB_AUTOREPLY_SUBJECT_A: Incomplete
PR_EMS_AB_AUTOREPLY_SUBJECT_W: Incomplete
PR_EMS_AB_BRIDGEHEAD_SERVERS: Incomplete
PR_EMS_AB_BRIDGEHEAD_SERVERS_A: Incomplete
PR_EMS_AB_BRIDGEHEAD_SERVERS_W: Incomplete
PR_EMS_AB_BRIDGEHEAD_SERVERS_O: Incomplete
PR_EMS_AB_BRIDGEHEAD_SERVERS_T: Incomplete
PR_EMS_AB_BUSINESS_CATEGORY: Incomplete
PR_EMS_AB_BUSINESS_CATEGORY_A: Incomplete
PR_EMS_AB_BUSINESS_CATEGORY_W: Incomplete
PR_EMS_AB_BUSINESS_ROLES: Incomplete
PR_EMS_AB_CA_CERTIFICATE: Incomplete
PR_EMS_AB_CAN_CREATE_PF: Incomplete
PR_EMS_AB_CAN_CREATE_PF_A: Incomplete
PR_EMS_AB_CAN_CREATE_PF_W: Incomplete
PR_EMS_AB_CAN_CREATE_PF_O: Incomplete
PR_EMS_AB_CAN_CREATE_PF_T: Incomplete
PR_EMS_AB_CAN_CREATE_PF_BL: Incomplete
PR_EMS_AB_CAN_CREATE_PF_BL_A: Incomplete
PR_EMS_AB_CAN_CREATE_PF_BL_W: Incomplete
PR_EMS_AB_CAN_CREATE_PF_BL_O: Incomplete
PR_EMS_AB_CAN_CREATE_PF_BL_T: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL_A: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL_W: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL_O: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL_T: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL_BL: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL_BL_A: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL_BL_W: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL_BL_O: Incomplete
PR_EMS_AB_CAN_CREATE_PF_DL_BL_T: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_A: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_W: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_O: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_T: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_BL: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_BL_A: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_BL_W: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_BL_O: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_BL_T: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL_A: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL_W: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL_O: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL_T: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_A: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_W: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_O: Incomplete
PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_T: Incomplete
PR_EMS_AB_CAN_PRESERVE_DNS: Incomplete
PR_EMS_AB_CERTIFICATE_REVOCATION_LIST: Incomplete
PR_EMS_AB_CLOCK_ALERT_OFFSET: Incomplete
PR_EMS_AB_CLOCK_ALERT_REPAIR: Incomplete
PR_EMS_AB_CLOCK_WARNING_OFFSET: Incomplete
PR_EMS_AB_CLOCK_WARNING_REPAIR: Incomplete
PR_EMS_AB_COMPUTER_NAME: Incomplete
PR_EMS_AB_COMPUTER_NAME_A: Incomplete
PR_EMS_AB_COMPUTER_NAME_W: Incomplete
PR_EMS_AB_CONNECTED_DOMAINS: Incomplete
PR_EMS_AB_CONNECTED_DOMAINS_A: Incomplete
PR_EMS_AB_CONNECTED_DOMAINS_W: Incomplete
PR_EMS_AB_CONTAINER_INFO: Incomplete
PR_EMS_AB_COST: Incomplete
PR_EMS_AB_COUNTRY_NAME: Incomplete
PR_EMS_AB_COUNTRY_NAME_A: Incomplete
PR_EMS_AB_COUNTRY_NAME_W: Incomplete
PR_EMS_AB_CROSS_CERTIFICATE_PAIR: Incomplete
PR_EMS_AB_DELIV_CONT_LENGTH: Incomplete
PR_EMS_AB_DELIV_EITS: Incomplete
PR_EMS_AB_DELIV_EXT_CONT_TYPES: Incomplete
PR_EMS_AB_DELIVER_AND_REDIRECT: Incomplete
PR_EMS_AB_DELIVERY_MECHANISM: Incomplete
PR_EMS_AB_DESCRIPTION: Incomplete
PR_EMS_AB_DESCRIPTION_A: Incomplete
PR_EMS_AB_DESCRIPTION_W: Incomplete
PR_EMS_AB_DESTINATION_INDICATOR: Incomplete
PR_EMS_AB_DESTINATION_INDICATOR_A: Incomplete
PR_EMS_AB_DESTINATION_INDICATOR_W: Incomplete
PR_EMS_AB_DIAGNOSTIC_REG_KEY: Incomplete
PR_EMS_AB_DIAGNOSTIC_REG_KEY_A: Incomplete
PR_EMS_AB_DIAGNOSTIC_REG_KEY_W: Incomplete
PR_EMS_AB_DISPLAY_NAME_OVERRIDE: Incomplete
PR_EMS_AB_DL_MEM_REJECT_PERMS_BL: Incomplete
PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_A: Incomplete
PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_W: Incomplete
PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_O: Incomplete
PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_T: Incomplete
PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL: Incomplete
PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_A: Incomplete
PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_W: Incomplete
PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_O: Incomplete
PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_T: Incomplete
PR_EMS_AB_DL_MEMBER_RULE: Incomplete
PR_EMS_AB_DOMAIN_DEF_ALT_RECIP: Incomplete
PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_A: Incomplete
PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_W: Incomplete
PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_O: Incomplete
PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_T: Incomplete
PR_EMS_AB_DOMAIN_NAME: Incomplete
PR_EMS_AB_DOMAIN_NAME_A: Incomplete
PR_EMS_AB_DOMAIN_NAME_W: Incomplete
PR_EMS_AB_DSA_SIGNATURE: Incomplete
PR_EMS_AB_DXA_ADMIN_COPY: Incomplete
PR_EMS_AB_DXA_ADMIN_FORWARD: Incomplete
PR_EMS_AB_DXA_ADMIN_UPDATE: Incomplete
PR_EMS_AB_DXA_APPEND_REQCN: Incomplete
PR_EMS_AB_DXA_CONF_CONTAINER_LIST: Incomplete
PR_EMS_AB_DXA_CONF_CONTAINER_LIST_A: Incomplete
PR_EMS_AB_DXA_CONF_CONTAINER_LIST_W: Incomplete
PR_EMS_AB_DXA_CONF_CONTAINER_LIST_O: Incomplete
PR_EMS_AB_DXA_CONF_CONTAINER_LIST_T: Incomplete
PR_EMS_AB_DXA_CONF_REQ_TIME: Incomplete
PR_EMS_AB_DXA_CONF_SEQ: Incomplete
PR_EMS_AB_DXA_CONF_SEQ_A: Incomplete
PR_EMS_AB_DXA_CONF_SEQ_W: Incomplete
PR_EMS_AB_DXA_CONF_SEQ_USN: Incomplete
PR_EMS_AB_DXA_EXCHANGE_OPTIONS: Incomplete
PR_EMS_AB_DXA_EXPORT_NOW: Incomplete
PR_EMS_AB_DXA_FLAGS: Incomplete
PR_EMS_AB_DXA_IMP_SEQ: Incomplete
PR_EMS_AB_DXA_IMP_SEQ_A: Incomplete
PR_EMS_AB_DXA_IMP_SEQ_W: Incomplete
PR_EMS_AB_DXA_IMP_SEQ_TIME: Incomplete
PR_EMS_AB_DXA_IMP_SEQ_USN: Incomplete
PR_EMS_AB_DXA_IMPORT_NOW: Incomplete
PR_EMS_AB_DXA_IN_TEMPLATE_MAP: Incomplete
PR_EMS_AB_DXA_IN_TEMPLATE_MAP_A: Incomplete
PR_EMS_AB_DXA_IN_TEMPLATE_MAP_W: Incomplete
PR_EMS_AB_DXA_LOCAL_ADMIN: Incomplete
PR_EMS_AB_DXA_LOCAL_ADMIN_A: Incomplete
PR_EMS_AB_DXA_LOCAL_ADMIN_W: Incomplete
PR_EMS_AB_DXA_LOCAL_ADMIN_O: Incomplete
PR_EMS_AB_DXA_LOCAL_ADMIN_T: Incomplete
PR_EMS_AB_DXA_LOGGING_LEVEL: Incomplete
PR_EMS_AB_DXA_NATIVE_ADDRESS_TYPE: Incomplete
PR_EMS_AB_DXA_NATIVE_ADDRESS_TYPE_A: Incomplete
PR_EMS_AB_DXA_NATIVE_ADDRESS_TYPE_W: Incomplete
PR_EMS_AB_DXA_OUT_TEMPLATE_MAP: Incomplete
PR_EMS_AB_DXA_OUT_TEMPLATE_MAP_A: Incomplete
PR_EMS_AB_DXA_OUT_TEMPLATE_MAP_W: Incomplete
PR_EMS_AB_DXA_PASSWORD: Incomplete
PR_EMS_AB_DXA_PASSWORD_A: Incomplete
PR_EMS_AB_DXA_PASSWORD_W: Incomplete
PR_EMS_AB_DXA_PREV_EXCHANGE_OPTIONS: Incomplete
PR_EMS_AB_DXA_PREV_EXPORT_NATIVE_ONLY: Incomplete
PR_EMS_AB_DXA_PREV_IN_EXCHANGE_SENSITIVITY: Incomplete
PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES: Incomplete
PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_A: Incomplete
PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_W: Incomplete
PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_O: Incomplete
PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_T: Incomplete
PR_EMS_AB_DXA_PREV_REPLICATION_SENSITIVITY: Incomplete
PR_EMS_AB_DXA_PREV_TEMPLATE_OPTIONS: Incomplete
PR_EMS_AB_DXA_PREV_TYPES: Incomplete
PR_EMS_AB_DXA_RECIPIENT_CP: Incomplete
PR_EMS_AB_DXA_RECIPIENT_CP_A: Incomplete
PR_EMS_AB_DXA_RECIPIENT_CP_W: Incomplete
PR_EMS_AB_DXA_REMOTE_CLIENT: Incomplete
PR_EMS_AB_DXA_REMOTE_CLIENT_A: Incomplete
PR_EMS_AB_DXA_REMOTE_CLIENT_W: Incomplete
PR_EMS_AB_DXA_REMOTE_CLIENT_O: Incomplete
PR_EMS_AB_DXA_REMOTE_CLIENT_T: Incomplete
PR_EMS_AB_DXA_REQ_SEQ: Incomplete
PR_EMS_AB_DXA_REQ_SEQ_A: Incomplete
PR_EMS_AB_DXA_REQ_SEQ_W: Incomplete
PR_EMS_AB_DXA_REQ_SEQ_TIME: Incomplete
PR_EMS_AB_DXA_REQ_SEQ_USN: Incomplete
PR_EMS_AB_DXA_REQNAME: Incomplete
PR_EMS_AB_DXA_REQNAME_A: Incomplete
PR_EMS_AB_DXA_REQNAME_W: Incomplete
PR_EMS_AB_DXA_SVR_SEQ: Incomplete
PR_EMS_AB_DXA_SVR_SEQ_A: Incomplete
PR_EMS_AB_DXA_SVR_SEQ_W: Incomplete
PR_EMS_AB_DXA_SVR_SEQ_TIME: Incomplete
PR_EMS_AB_DXA_SVR_SEQ_USN: Incomplete
PR_EMS_AB_DXA_TASK: Incomplete
PR_EMS_AB_DXA_TEMPLATE_OPTIONS: Incomplete
PR_EMS_AB_DXA_TEMPLATE_TIMESTAMP: Incomplete
PR_EMS_AB_DXA_TYPES: Incomplete
PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST: Incomplete
PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_A: Incomplete
PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_W: Incomplete
PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_O: Incomplete
PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_T: Incomplete
PR_EMS_AB_ENABLED_PROTOCOLS: Incomplete
PR_EMS_AB_ENCAPSULATION_METHOD: Incomplete
PR_EMS_AB_ENCRYPT: Incomplete
PR_EMS_AB_ENCRYPT_ALG_LIST_NA: Incomplete
PR_EMS_AB_ENCRYPT_ALG_LIST_NA_A: Incomplete
PR_EMS_AB_ENCRYPT_ALG_LIST_NA_W: Incomplete
PR_EMS_AB_ENCRYPT_ALG_LIST_OTHER: Incomplete
PR_EMS_AB_ENCRYPT_ALG_LIST_OTHER_A: Incomplete
PR_EMS_AB_ENCRYPT_ALG_LIST_OTHER_W: Incomplete
PR_EMS_AB_ENCRYPT_ALG_SELECTED_NA: Incomplete
PR_EMS_AB_ENCRYPT_ALG_SELECTED_NA_A: Incomplete
PR_EMS_AB_ENCRYPT_ALG_SELECTED_NA_W: Incomplete
PR_EMS_AB_ENCRYPT_ALG_SELECTED_OTHER: Incomplete
PR_EMS_AB_ENCRYPT_ALG_SELECTED_OTHER_A: Incomplete
PR_EMS_AB_ENCRYPT_ALG_SELECTED_OTHER_W: Incomplete
PR_EMS_AB_EXPAND_DLS_LOCALLY: Incomplete
PR_EMS_AB_EXPIRATION_TIME: Incomplete
PR_EMS_AB_EXPORT_CONTAINERS: Incomplete
PR_EMS_AB_EXPORT_CONTAINERS_A: Incomplete
PR_EMS_AB_EXPORT_CONTAINERS_W: Incomplete
PR_EMS_AB_EXPORT_CONTAINERS_O: Incomplete
PR_EMS_AB_EXPORT_CONTAINERS_T: Incomplete
PR_EMS_AB_EXPORT_CUSTOM_RECIPIENTS: Incomplete
PR_EMS_AB_EXTENDED_CHARS_ALLOWED: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_1: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_1_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_1_W: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_10: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_10_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_10_W: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_2: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_2_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_2_W: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_3: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_3_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_3_W: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_4: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_4_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_4_W: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_5: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_5_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_5_W: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_6: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_6_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_6_W: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_7: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_7_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_7_W: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_8: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_8_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_8_W: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_9: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_9_A: Incomplete
PR_EMS_AB_EXTENSION_ATTRIBUTE_9_W: Incomplete
PR_EMS_AB_EXTENSION_DATA: Incomplete
PR_EMS_AB_EXTENSION_NAME: Incomplete
PR_EMS_AB_EXTENSION_NAME_A: Incomplete
PR_EMS_AB_EXTENSION_NAME_W: Incomplete
PR_EMS_AB_EXTENSION_NAME_INHERITED: Incomplete
PR_EMS_AB_EXTENSION_NAME_INHERITED_A: Incomplete
PR_EMS_AB_EXTENSION_NAME_INHERITED_W: Incomplete
PR_EMS_AB_FACSIMILE_TELEPHONE_NUMBER: Incomplete
PR_EMS_AB_FILE_VERSION: Incomplete
PR_EMS_AB_FILTER_LOCAL_ADDRESSES: Incomplete
PR_EMS_AB_FOLDER_PATHNAME: Incomplete
PR_EMS_AB_FOLDER_PATHNAME_A: Incomplete
PR_EMS_AB_FOLDER_PATHNAME_W: Incomplete
PR_EMS_AB_FOLDERS_CONTAINER: Incomplete
PR_EMS_AB_FOLDERS_CONTAINER_A: Incomplete
PR_EMS_AB_FOLDERS_CONTAINER_W: Incomplete
PR_EMS_AB_FOLDERS_CONTAINER_O: Incomplete
PR_EMS_AB_FOLDERS_CONTAINER_T: Incomplete
PR_EMS_AB_GARBAGE_COLL_PERIOD: Incomplete
PR_EMS_AB_GATEWAY_LOCAL_CRED: Incomplete
PR_EMS_AB_GATEWAY_LOCAL_CRED_A: Incomplete
PR_EMS_AB_GATEWAY_LOCAL_CRED_W: Incomplete
PR_EMS_AB_GATEWAY_LOCAL_DESIG: Incomplete
PR_EMS_AB_GATEWAY_LOCAL_DESIG_A: Incomplete
PR_EMS_AB_GATEWAY_LOCAL_DESIG_W: Incomplete
PR_EMS_AB_GATEWAY_PROXY: Incomplete
PR_EMS_AB_GATEWAY_PROXY_A: Incomplete
PR_EMS_AB_GATEWAY_PROXY_W: Incomplete
PR_EMS_AB_GATEWAY_ROUTING_TREE: Incomplete
PR_EMS_AB_GWART_LAST_MODIFIED: Incomplete
PR_EMS_AB_HAS_FULL_REPLICA_NCS: Incomplete
PR_EMS_AB_HAS_FULL_REPLICA_NCS_A: Incomplete
PR_EMS_AB_HAS_FULL_REPLICA_NCS_W: Incomplete
PR_EMS_AB_HAS_FULL_REPLICA_NCS_O: Incomplete
PR_EMS_AB_HAS_FULL_REPLICA_NCS_T: Incomplete
PR_EMS_AB_HAS_MASTER_NCS: Incomplete
PR_EMS_AB_HAS_MASTER_NCS_A: Incomplete
PR_EMS_AB_HAS_MASTER_NCS_W: Incomplete
PR_EMS_AB_HAS_MASTER_NCS_O: Incomplete
PR_EMS_AB_HAS_MASTER_NCS_T: Incomplete
PR_EMS_AB_HELP_DATA16: Incomplete
PR_EMS_AB_HELP_DATA32: Incomplete
PR_EMS_AB_HELP_FILE_NAME: Incomplete
PR_EMS_AB_HELP_FILE_NAME_A: Incomplete
PR_EMS_AB_HELP_FILE_NAME_W: Incomplete
PR_EMS_AB_HEURISTICS: Incomplete
PR_EMS_AB_HIDE_DL_MEMBERSHIP: Incomplete
PR_EMS_AB_HIDE_FROM_ADDRESS_BOOK: Incomplete
PR_EMS_AB_HOME_MDB: Incomplete
PR_EMS_AB_HOME_MDB_A: Incomplete
PR_EMS_AB_HOME_MDB_W: Incomplete
PR_EMS_AB_HOME_MDB_O: Incomplete
PR_EMS_AB_HOME_MDB_T: Incomplete
PR_EMS_AB_HOME_MDB_BL: Incomplete
PR_EMS_AB_HOME_MDB_BL_A: Incomplete
PR_EMS_AB_HOME_MDB_BL_W: Incomplete
PR_EMS_AB_HOME_MDB_BL_O: Incomplete
PR_EMS_AB_HOME_MDB_BL_T: Incomplete
PR_EMS_AB_HOME_MTA: Incomplete
PR_EMS_AB_HOME_MTA_A: Incomplete
PR_EMS_AB_HOME_MTA_W: Incomplete
PR_EMS_AB_HOME_MTA_O: Incomplete
PR_EMS_AB_HOME_MTA_T: Incomplete
PR_EMS_AB_HOME_PUBLIC_SERVER: Incomplete
PR_EMS_AB_HOME_PUBLIC_SERVER_A: Incomplete
PR_EMS_AB_HOME_PUBLIC_SERVER_W: Incomplete
PR_EMS_AB_HOME_PUBLIC_SERVER_O: Incomplete
PR_EMS_AB_HOME_PUBLIC_SERVER_T: Incomplete
PR_EMS_AB_IMPORT_CONTAINER: Incomplete
PR_EMS_AB_IMPORT_CONTAINER_A: Incomplete
PR_EMS_AB_IMPORT_CONTAINER_W: Incomplete
PR_EMS_AB_IMPORT_CONTAINER_O: Incomplete
PR_EMS_AB_IMPORT_CONTAINER_T: Incomplete
PR_EMS_AB_IMPORT_SENSITIVITY: Incomplete
PR_EMS_AB_IMPORTED_FROM: Incomplete
PR_EMS_AB_IMPORTED_FROM_A: Incomplete
PR_EMS_AB_IMPORTED_FROM_W: Incomplete
PR_EMS_AB_INBOUND_SITES: Incomplete
PR_EMS_AB_INBOUND_SITES_A: Incomplete
PR_EMS_AB_INBOUND_SITES_W: Incomplete
PR_EMS_AB_INBOUND_SITES_O: Incomplete
PR_EMS_AB_INBOUND_SITES_T: Incomplete
PR_EMS_AB_INSTANCE_TYPE: Incomplete
PR_EMS_AB_INTERNATIONAL_ISDN_NUMBER: Incomplete
PR_EMS_AB_INTERNATIONAL_ISDN_NUMBER_A: Incomplete
PR_EMS_AB_INTERNATIONAL_ISDN_NUMBER_W: Incomplete
PR_EMS_AB_INVOCATION_ID: Incomplete
PR_EMS_AB_IS_DELETED: Incomplete
PR_EMS_AB_IS_MEMBER_OF_DL: Incomplete
PR_EMS_AB_IS_MEMBER_OF_DL_A: Incomplete
PR_EMS_AB_IS_MEMBER_OF_DL_W: Incomplete
PR_EMS_AB_IS_MEMBER_OF_DL_O: Incomplete
PR_EMS_AB_IS_MEMBER_OF_DL_T: Incomplete
PR_EMS_AB_IS_SINGLE_VALUED: Incomplete
PR_EMS_AB_KCC_STATUS: Incomplete
PR_EMS_AB_KM_SERVER: Incomplete
PR_EMS_AB_KM_SERVER_A: Incomplete
PR_EMS_AB_KM_SERVER_W: Incomplete
PR_EMS_AB_KM_SERVER_O: Incomplete
PR_EMS_AB_KM_SERVER_T: Incomplete
PR_EMS_AB_KNOWLEDGE_INFORMATION: Incomplete
PR_EMS_AB_KNOWLEDGE_INFORMATION_A: Incomplete
PR_EMS_AB_KNOWLEDGE_INFORMATION_W: Incomplete
PR_EMS_AB_LANGUAGE: Incomplete
PR_EMS_AB_LDAP_DISPLAY_NAME: Incomplete
PR_EMS_AB_LDAP_DISPLAY_NAME_A: Incomplete
PR_EMS_AB_LDAP_DISPLAY_NAME_W: Incomplete
PR_EMS_AB_LINE_WRAP: Incomplete
PR_EMS_AB_LINK_ID: Incomplete
PR_EMS_AB_LOCAL_BRIDGE_HEAD: Incomplete
PR_EMS_AB_LOCAL_BRIDGE_HEAD_A: Incomplete
PR_EMS_AB_LOCAL_BRIDGE_HEAD_W: Incomplete
PR_EMS_AB_LOCAL_BRIDGE_HEAD_ADDRESS: Incomplete
PR_EMS_AB_LOCAL_BRIDGE_HEAD_ADDRESS_A: Incomplete
PR_EMS_AB_LOCAL_BRIDGE_HEAD_ADDRESS_W: Incomplete
PR_EMS_AB_LOCAL_INITIAL_TURN: Incomplete
PR_EMS_AB_LOCAL_SCOPE: Incomplete
PR_EMS_AB_LOCAL_SCOPE_A: Incomplete
PR_EMS_AB_LOCAL_SCOPE_W: Incomplete
PR_EMS_AB_LOCAL_SCOPE_O: Incomplete
PR_EMS_AB_LOCAL_SCOPE_T: Incomplete
PR_EMS_AB_LOG_FILENAME: Incomplete
PR_EMS_AB_LOG_FILENAME_A: Incomplete
PR_EMS_AB_LOG_FILENAME_W: Incomplete
PR_EMS_AB_LOG_ROLLOVER_INTERVAL: Incomplete
PR_EMS_AB_MAINTAIN_AUTOREPLY_HISTORY: Incomplete
PR_EMS_AB_MANAGER: Incomplete
PR_EMS_AB_MANAGER_A: Incomplete
PR_EMS_AB_MANAGER_W: Incomplete
PR_EMS_AB_MANAGER_O: Incomplete
PR_EMS_AB_MANAGER_T: Incomplete
PR_EMS_AB_MAPI_DISPLAY_TYPE: Incomplete
PR_EMS_AB_MAPI_ID: Incomplete
PR_EMS_AB_MAXIMUM_OBJECT_ID: Incomplete
PR_EMS_AB_MDB_BACKOFF_INTERVAL: Incomplete
PR_EMS_AB_MDB_MSG_TIME_OUT_PERIOD: Incomplete
PR_EMS_AB_MDB_OVER_QUOTA_LIMIT: Incomplete
PR_EMS_AB_MDB_STORAGE_QUOTA: Incomplete
PR_EMS_AB_MDB_UNREAD_LIMIT: Incomplete
PR_EMS_AB_MDB_USE_DEFAULTS: Incomplete
PR_EMS_AB_MEMBER: Incomplete
PR_EMS_AB_MEMBER_A: Incomplete
PR_EMS_AB_MEMBER_W: Incomplete
PR_EMS_AB_MEMBER_O: Incomplete
PR_EMS_AB_MEMBER_T: Incomplete
PR_EMS_AB_MESSAGE_TRACKING_ENABLED: Incomplete
PR_EMS_AB_MONITOR_CLOCK: Incomplete
PR_EMS_AB_MONITOR_SERVERS: Incomplete
PR_EMS_AB_MONITOR_SERVICES: Incomplete
PR_EMS_AB_MONITORED_CONFIGURATIONS: Incomplete
PR_EMS_AB_MONITORED_CONFIGURATIONS_A: Incomplete
PR_EMS_AB_MONITORED_CONFIGURATIONS_W: Incomplete
PR_EMS_AB_MONITORED_CONFIGURATIONS_O: Incomplete
PR_EMS_AB_MONITORED_CONFIGURATIONS_T: Incomplete
PR_EMS_AB_MONITORED_SERVERS: Incomplete
PR_EMS_AB_MONITORED_SERVERS_A: Incomplete
PR_EMS_AB_MONITORED_SERVERS_W: Incomplete
PR_EMS_AB_MONITORED_SERVERS_O: Incomplete
PR_EMS_AB_MONITORED_SERVERS_T: Incomplete
PR_EMS_AB_MONITORED_SERVICES: Incomplete
PR_EMS_AB_MONITORED_SERVICES_A: Incomplete
PR_EMS_AB_MONITORED_SERVICES_W: Incomplete
PR_EMS_AB_MONITORING_ALERT_DELAY: Incomplete
PR_EMS_AB_MONITORING_ALERT_UNITS: Incomplete
PR_EMS_AB_MONITORING_AVAILABILITY_STYLE: Incomplete
PR_EMS_AB_MONITORING_AVAILABILITY_WINDOW: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_MAIL: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_A: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_W: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_O: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_T: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_RPC: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_RPC_A: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_RPC_W: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_RPC_O: Incomplete
PR_EMS_AB_MONITORING_CACHED_VIA_RPC_T: Incomplete
PR_EMS_AB_MONITORING_ESCALATION_PROCEDURE: Incomplete
PR_EMS_AB_MONITORING_HOTSITE_POLL_INTERVAL: Incomplete
PR_EMS_AB_MONITORING_HOTSITE_POLL_UNITS: Incomplete
PR_EMS_AB_MONITORING_MAIL_UPDATE_INTERVAL: Incomplete
PR_EMS_AB_MONITORING_MAIL_UPDATE_UNITS: Incomplete
PR_EMS_AB_MONITORING_NORMAL_POLL_INTERVAL: Incomplete
PR_EMS_AB_MONITORING_NORMAL_POLL_UNITS: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS_A: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS_W: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS_O: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS_T: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS_NDR: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS_NDR_A: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS_NDR_W: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS_NDR_O: Incomplete
PR_EMS_AB_MONITORING_RECIPIENTS_NDR_T: Incomplete
PR_EMS_AB_MONITORING_RPC_UPDATE_INTERVAL: Incomplete
PR_EMS_AB_MONITORING_RPC_UPDATE_UNITS: Incomplete
PR_EMS_AB_MONITORING_WARNING_DELAY: Incomplete
PR_EMS_AB_MONITORING_WARNING_UNITS: Incomplete
PR_EMS_AB_MTA_LOCAL_CRED: Incomplete
PR_EMS_AB_MTA_LOCAL_CRED_A: Incomplete
PR_EMS_AB_MTA_LOCAL_CRED_W: Incomplete
PR_EMS_AB_MTA_LOCAL_DESIG: Incomplete
PR_EMS_AB_MTA_LOCAL_DESIG_A: Incomplete
PR_EMS_AB_MTA_LOCAL_DESIG_W: Incomplete
PR_EMS_AB_N_ADDRESS: Incomplete
PR_EMS_AB_N_ADDRESS_TYPE: Incomplete
PR_EMS_AB_NETWORK_ADDRESS: Incomplete
PR_EMS_AB_NETWORK_ADDRESS_A: Incomplete
PR_EMS_AB_NETWORK_ADDRESS_W: Incomplete
PR_EMS_AB_NNTP_CHARACTER_SET: Incomplete
PR_EMS_AB_NNTP_CHARACTER_SET_A: Incomplete
PR_EMS_AB_NNTP_CHARACTER_SET_W: Incomplete
PR_EMS_AB_NNTP_CONTENT_FORMAT: Incomplete
PR_EMS_AB_NNTP_CONTENT_FORMAT_A: Incomplete
PR_EMS_AB_NNTP_CONTENT_FORMAT_W: Incomplete
PR_EMS_AB_NT_MACHINE_NAME: Incomplete
PR_EMS_AB_NT_MACHINE_NAME_A: Incomplete
PR_EMS_AB_NT_MACHINE_NAME_W: Incomplete
PR_EMS_AB_NT_SECURITY_DESCRIPTOR: Incomplete
PR_EMS_AB_NUM_OF_OPEN_RETRIES: Incomplete
PR_EMS_AB_NUM_OF_TRANSFER_RETRIES: Incomplete
PR_EMS_AB_OBJ_DIST_NAME: Incomplete
PR_EMS_AB_OBJ_DIST_NAME_A: Incomplete
PR_EMS_AB_OBJ_DIST_NAME_W: Incomplete
PR_EMS_AB_OBJ_DIST_NAME_O: Incomplete
PR_EMS_AB_OBJ_DIST_NAME_T: Incomplete
PR_EMS_AB_OBJECT_CLASS_CATEGORY: Incomplete
PR_EMS_AB_OBJECT_VERSION: Incomplete
PR_EMS_AB_OFF_LINE_AB_CONTAINERS: Incomplete
PR_EMS_AB_OFF_LINE_AB_CONTAINERS_A: Incomplete
PR_EMS_AB_OFF_LINE_AB_CONTAINERS_W: Incomplete
PR_EMS_AB_OFF_LINE_AB_CONTAINERS_O: Incomplete
PR_EMS_AB_OFF_LINE_AB_CONTAINERS_T: Incomplete
PR_EMS_AB_OFF_LINE_AB_SCHEDULE: Incomplete
PR_EMS_AB_OFF_LINE_AB_SERVER: Incomplete
PR_EMS_AB_OFF_LINE_AB_SERVER_A: Incomplete
PR_EMS_AB_OFF_LINE_AB_SERVER_W: Incomplete
PR_EMS_AB_OFF_LINE_AB_SERVER_O: Incomplete
PR_EMS_AB_OFF_LINE_AB_SERVER_T: Incomplete
PR_EMS_AB_OFF_LINE_AB_STYLE: Incomplete
PR_EMS_AB_OID_TYPE: Incomplete
PR_EMS_AB_OM_OBJECT_CLASS: Incomplete
PR_EMS_AB_OM_SYNTAX: Incomplete
PR_EMS_AB_OOF_REPLY_TO_ORIGINATOR: Incomplete
PR_EMS_AB_OPEN_RETRY_INTERVAL: Incomplete
PR_EMS_AB_ORGANIZATION_NAME: Incomplete
PR_EMS_AB_ORGANIZATION_NAME_A: Incomplete
PR_EMS_AB_ORGANIZATION_NAME_W: Incomplete
PR_EMS_AB_ORGANIZATIONAL_UNIT_NAME: Incomplete
PR_EMS_AB_ORGANIZATIONAL_UNIT_NAME_A: Incomplete
PR_EMS_AB_ORGANIZATIONAL_UNIT_NAME_W: Incomplete
PR_EMS_AB_ORIGINAL_DISPLAY_TABLE: Incomplete
PR_EMS_AB_ORIGINAL_DISPLAY_TABLE_MSDOS: Incomplete
PR_EMS_AB_OUTBOUND_SITES: Incomplete
PR_EMS_AB_OUTBOUND_SITES_A: Incomplete
PR_EMS_AB_OUTBOUND_SITES_W: Incomplete
PR_EMS_AB_OUTBOUND_SITES_O: Incomplete
PR_EMS_AB_OUTBOUND_SITES_T: Incomplete
PR_EMS_AB_OWNER: Incomplete
PR_EMS_AB_OWNER_A: Incomplete
PR_EMS_AB_OWNER_W: Incomplete
PR_EMS_AB_OWNER_O: Incomplete
PR_EMS_AB_OWNER_T: Incomplete
PR_EMS_AB_OWNER_BL: Incomplete
PR_EMS_AB_OWNER_BL_A: Incomplete
PR_EMS_AB_OWNER_BL_W: Incomplete
PR_EMS_AB_OWNER_BL_O: Incomplete
PR_EMS_AB_OWNER_BL_T: Incomplete
PR_EMS_AB_P_SELECTOR: Incomplete
PR_EMS_AB_P_SELECTOR_INBOUND: Incomplete
PR_EMS_AB_PER_MSG_DIALOG_DISPLAY_TABLE: Incomplete
PR_EMS_AB_PER_RECIP_DIALOG_DISPLAY_TABLE: Incomplete
PR_EMS_AB_PERIOD_REP_SYNC_TIMES: Incomplete
PR_EMS_AB_PERIOD_REPL_STAGGER: Incomplete
PR_EMS_AB_PF_CONTACTS: Incomplete
PR_EMS_AB_PF_CONTACTS_A: Incomplete
PR_EMS_AB_PF_CONTACTS_W: Incomplete
PR_EMS_AB_PF_CONTACTS_O: Incomplete
PR_EMS_AB_PF_CONTACTS_T: Incomplete
PR_EMS_AB_POP_CHARACTER_SET: Incomplete
PR_EMS_AB_POP_CHARACTER_SET_A: Incomplete
PR_EMS_AB_POP_CHARACTER_SET_W: Incomplete
PR_EMS_AB_POP_CONTENT_FORMAT: Incomplete
PR_EMS_AB_POP_CONTENT_FORMAT_A: Incomplete
PR_EMS_AB_POP_CONTENT_FORMAT_W: Incomplete
PR_EMS_AB_POSTAL_ADDRESS: Incomplete
PR_EMS_AB_PREFERRED_DELIVERY_METHOD: Incomplete
PR_EMS_AB_PRMD: Incomplete
PR_EMS_AB_PRMD_A: Incomplete
PR_EMS_AB_PRMD_W: Incomplete
PR_EMS_AB_PROXY_ADDRESSES: Incomplete
PR_EMS_AB_PROXY_ADDRESSES_A: Incomplete
PR_EMS_AB_PROXY_ADDRESSES_W: Incomplete
PR_EMS_AB_PROXY_GENERATOR_DLL: Incomplete
PR_EMS_AB_PROXY_GENERATOR_DLL_A: Incomplete
PR_EMS_AB_PROXY_GENERATOR_DLL_W: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES_A: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES_W: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES_O: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES_T: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES_BL: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES_BL_A: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES_BL_W: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES_BL_O: Incomplete
PR_EMS_AB_PUBLIC_DELEGATES_BL_T: Incomplete
PR_EMS_AB_QUOTA_NOTIFICATION_SCHEDULE: Incomplete
PR_EMS_AB_QUOTA_NOTIFICATION_STYLE: Incomplete
PR_EMS_AB_RANGE_LOWER: Incomplete
PR_EMS_AB_RANGE_UPPER: Incomplete
PR_EMS_AB_RAS_CALLBACK_NUMBER: Incomplete
PR_EMS_AB_RAS_CALLBACK_NUMBER_A: Incomplete
PR_EMS_AB_RAS_CALLBACK_NUMBER_W: Incomplete
PR_EMS_AB_RAS_PHONE_NUMBER: Incomplete
PR_EMS_AB_RAS_PHONE_NUMBER_A: Incomplete
PR_EMS_AB_RAS_PHONE_NUMBER_W: Incomplete
PR_EMS_AB_RAS_PHONEBOOK_ENTRY_NAME: Incomplete
PR_EMS_AB_RAS_PHONEBOOK_ENTRY_NAME_A: Incomplete
PR_EMS_AB_RAS_PHONEBOOK_ENTRY_NAME_W: Incomplete
PR_EMS_AB_RAS_REMOTE_SRVR_NAME: Incomplete
PR_EMS_AB_RAS_REMOTE_SRVR_NAME_A: Incomplete
PR_EMS_AB_RAS_REMOTE_SRVR_NAME_W: Incomplete
PR_EMS_AB_REGISTERED_ADDRESS: Incomplete
PR_EMS_AB_REMOTE_BRIDGE_HEAD: Incomplete
PR_EMS_AB_REMOTE_BRIDGE_HEAD_A: Incomplete
PR_EMS_AB_REMOTE_BRIDGE_HEAD_W: Incomplete
PR_EMS_AB_REMOTE_BRIDGE_HEAD_ADDRESS: Incomplete
PR_EMS_AB_REMOTE_BRIDGE_HEAD_ADDRESS_A: Incomplete
PR_EMS_AB_REMOTE_BRIDGE_HEAD_ADDRESS_W: Incomplete
PR_EMS_AB_REMOTE_OUT_BH_SERVER: Incomplete
PR_EMS_AB_REMOTE_OUT_BH_SERVER_A: Incomplete
PR_EMS_AB_REMOTE_OUT_BH_SERVER_W: Incomplete
PR_EMS_AB_REMOTE_OUT_BH_SERVER_O: Incomplete
PR_EMS_AB_REMOTE_OUT_BH_SERVER_T: Incomplete
PR_EMS_AB_REMOTE_SITE: Incomplete
PR_EMS_AB_REMOTE_SITE_A: Incomplete
PR_EMS_AB_REMOTE_SITE_W: Incomplete
PR_EMS_AB_REMOTE_SITE_O: Incomplete
PR_EMS_AB_REMOTE_SITE_T: Incomplete
PR_EMS_AB_REPLICATION_MAIL_MSG_SIZE: Incomplete
PR_EMS_AB_REPLICATION_SENSITIVITY: Incomplete
PR_EMS_AB_REPLICATION_STAGGER: Incomplete
PR_EMS_AB_REPORT_TO_ORIGINATOR: Incomplete
PR_EMS_AB_REPORT_TO_OWNER: Incomplete
PR_EMS_AB_REPORTS: Incomplete
PR_EMS_AB_REPORTS_A: Incomplete
PR_EMS_AB_REPORTS_W: Incomplete
PR_EMS_AB_REPORTS_O: Incomplete
PR_EMS_AB_REPORTS_T: Incomplete
PR_EMS_AB_REQ_SEQ: Incomplete
PR_EMS_AB_RESPONSIBLE_LOCAL_DXA: Incomplete
PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_A: Incomplete
PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_W: Incomplete
PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_O: Incomplete
PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_T: Incomplete
PR_EMS_AB_RID_SERVER: Incomplete
PR_EMS_AB_RID_SERVER_A: Incomplete
PR_EMS_AB_RID_SERVER_W: Incomplete
PR_EMS_AB_RID_SERVER_O: Incomplete
PR_EMS_AB_RID_SERVER_T: Incomplete
PR_EMS_AB_ROLE_OCCUPANT: Incomplete
PR_EMS_AB_ROLE_OCCUPANT_A: Incomplete
PR_EMS_AB_ROLE_OCCUPANT_W: Incomplete
PR_EMS_AB_ROLE_OCCUPANT_O: Incomplete
PR_EMS_AB_ROLE_OCCUPANT_T: Incomplete
PR_EMS_AB_ROUTING_LIST: Incomplete
PR_EMS_AB_ROUTING_LIST_A: Incomplete
PR_EMS_AB_ROUTING_LIST_W: Incomplete
PR_EMS_AB_RTS_CHECKPOINT_SIZE: Incomplete
PR_EMS_AB_RTS_RECOVERY_TIMEOUT: Incomplete
PR_EMS_AB_RTS_WINDOW_SIZE: Incomplete
PR_EMS_AB_RUNS_ON: Incomplete
PR_EMS_AB_RUNS_ON_A: Incomplete
PR_EMS_AB_RUNS_ON_W: Incomplete
PR_EMS_AB_RUNS_ON_O: Incomplete
PR_EMS_AB_RUNS_ON_T: Incomplete
PR_EMS_AB_S_SELECTOR: Incomplete
PR_EMS_AB_S_SELECTOR_INBOUND: Incomplete
PR_EMS_AB_SCHEMA_FLAGS: Incomplete
PR_EMS_AB_SCHEMA_VERSION: Incomplete
PR_EMS_AB_SEARCH_FLAGS: Incomplete
PR_EMS_AB_SEARCH_GUIDE: Incomplete
PR_EMS_AB_SECURITY_PROTOCOL: Incomplete
PR_EMS_AB_SEE_ALSO: Incomplete
PR_EMS_AB_SEE_ALSO_A: Incomplete
PR_EMS_AB_SEE_ALSO_W: Incomplete
PR_EMS_AB_SEE_ALSO_O: Incomplete
PR_EMS_AB_SEE_ALSO_T: Incomplete
PR_EMS_AB_SERIAL_NUMBER: Incomplete
PR_EMS_AB_SERIAL_NUMBER_A: Incomplete
PR_EMS_AB_SERIAL_NUMBER_W: Incomplete
PR_EMS_AB_SERVICE_ACTION_FIRST: Incomplete
PR_EMS_AB_SERVICE_ACTION_OTHER: Incomplete
PR_EMS_AB_SERVICE_ACTION_SECOND: Incomplete
PR_EMS_AB_SERVICE_RESTART_DELAY: Incomplete
PR_EMS_AB_SERVICE_RESTART_MESSAGE: Incomplete
PR_EMS_AB_SERVICE_RESTART_MESSAGE_A: Incomplete
PR_EMS_AB_SERVICE_RESTART_MESSAGE_W: Incomplete
PR_EMS_AB_SESSION_DISCONNECT_TIMER: Incomplete
PR_EMS_AB_SITE_AFFINITY: Incomplete
PR_EMS_AB_SITE_AFFINITY_A: Incomplete
PR_EMS_AB_SITE_AFFINITY_W: Incomplete
PR_EMS_AB_SITE_FOLDER_GUID: Incomplete
PR_EMS_AB_SITE_FOLDER_SERVER: Incomplete
PR_EMS_AB_SITE_FOLDER_SERVER_A: Incomplete
PR_EMS_AB_SITE_FOLDER_SERVER_W: Incomplete
PR_EMS_AB_SITE_FOLDER_SERVER_O: Incomplete
PR_EMS_AB_SITE_FOLDER_SERVER_T: Incomplete
PR_EMS_AB_SITE_PROXY_SPACE: Incomplete
PR_EMS_AB_SITE_PROXY_SPACE_A: Incomplete
PR_EMS_AB_SITE_PROXY_SPACE_W: Incomplete
PR_EMS_AB_SPACE_LAST_COMPUTED: Incomplete
PR_EMS_AB_STREET_ADDRESS: Incomplete
PR_EMS_AB_STREET_ADDRESS_A: Incomplete
PR_EMS_AB_STREET_ADDRESS_W: Incomplete
PR_EMS_AB_SUB_REFS: Incomplete
PR_EMS_AB_SUB_REFS_A: Incomplete
PR_EMS_AB_SUB_REFS_W: Incomplete
PR_EMS_AB_SUB_REFS_O: Incomplete
PR_EMS_AB_SUB_REFS_T: Incomplete
PR_EMS_AB_SUB_SITE: Incomplete
PR_EMS_AB_SUB_SITE_A: Incomplete
PR_EMS_AB_SUB_SITE_W: Incomplete
PR_EMS_AB_SUBMISSION_CONT_LENGTH: Incomplete
PR_EMS_AB_SUPPORTED_APPLICATION_CONTEXT: Incomplete
PR_EMS_AB_SUPPORTING_STACK: Incomplete
PR_EMS_AB_SUPPORTING_STACK_A: Incomplete
PR_EMS_AB_SUPPORTING_STACK_W: Incomplete
PR_EMS_AB_SUPPORTING_STACK_O: Incomplete
PR_EMS_AB_SUPPORTING_STACK_T: Incomplete
PR_EMS_AB_SUPPORTING_STACK_BL: Incomplete
PR_EMS_AB_SUPPORTING_STACK_BL_A: Incomplete
PR_EMS_AB_SUPPORTING_STACK_BL_W: Incomplete
PR_EMS_AB_SUPPORTING_STACK_BL_O: Incomplete
PR_EMS_AB_SUPPORTING_STACK_BL_T: Incomplete
PR_EMS_AB_T_SELECTOR: Incomplete
PR_EMS_AB_T_SELECTOR_INBOUND: Incomplete
PR_EMS_AB_TARGET_ADDRESS: Incomplete
PR_EMS_AB_TARGET_ADDRESS_A: Incomplete
PR_EMS_AB_TARGET_ADDRESS_W: Incomplete
PR_EMS_AB_TARGET_MTAS: Incomplete
PR_EMS_AB_TARGET_MTAS_A: Incomplete
PR_EMS_AB_TARGET_MTAS_W: Incomplete
PR_EMS_AB_TELEPHONE_NUMBER: Incomplete
PR_EMS_AB_TELEPHONE_NUMBER_A: Incomplete
PR_EMS_AB_TELEPHONE_NUMBER_W: Incomplete
PR_EMS_AB_TELETEX_TERMINAL_IDENTIFIER: Incomplete
PR_EMS_AB_TEMP_ASSOC_THRESHOLD: Incomplete
PR_EMS_AB_TOMBSTONE_LIFETIME: Incomplete
PR_EMS_AB_TRACKING_LOG_PATH_NAME: Incomplete
PR_EMS_AB_TRACKING_LOG_PATH_NAME_A: Incomplete
PR_EMS_AB_TRACKING_LOG_PATH_NAME_W: Incomplete
PR_EMS_AB_TRANS_RETRY_MINS: Incomplete
PR_EMS_AB_TRANS_TIMEOUT_MINS: Incomplete
PR_EMS_AB_TRANSFER_RETRY_INTERVAL: Incomplete
PR_EMS_AB_TRANSFER_TIMEOUT_NON_URGENT: Incomplete
PR_EMS_AB_TRANSFER_TIMEOUT_NORMAL: Incomplete
PR_EMS_AB_TRANSFER_TIMEOUT_URGENT: Incomplete
PR_EMS_AB_TRANSLATION_TABLE_USED: Incomplete
PR_EMS_AB_TRANSPORT_EXPEDITED_DATA: Incomplete
PR_EMS_AB_TRUST_LEVEL: Incomplete
PR_EMS_AB_TURN_REQUEST_THRESHOLD: Incomplete
PR_EMS_AB_TWO_WAY_ALTERNATE_FACILITY: Incomplete
PR_EMS_AB_UNAUTH_ORIG_BL: Incomplete
PR_EMS_AB_UNAUTH_ORIG_BL_A: Incomplete
PR_EMS_AB_UNAUTH_ORIG_BL_W: Incomplete
PR_EMS_AB_UNAUTH_ORIG_BL_O: Incomplete
PR_EMS_AB_UNAUTH_ORIG_BL_T: Incomplete
PR_EMS_AB_USE_SERVER_VALUES: Incomplete
PR_EMS_AB_USER_PASSWORD: Incomplete
PR_EMS_AB_USN_CHANGED: Incomplete
PR_EMS_AB_USN_CREATED: Incomplete
PR_EMS_AB_USN_DSA_LAST_OBJ_REMOVED: Incomplete
PR_EMS_AB_USN_INTERSITE: Incomplete
PR_EMS_AB_USN_LAST_OBJ_REM: Incomplete
PR_EMS_AB_USN_SOURCE: Incomplete
PR_EMS_AB_WWW_HOME_PAGE: Incomplete
PR_EMS_AB_WWW_HOME_PAGE_A: Incomplete
PR_EMS_AB_WWW_HOME_PAGE_W: Incomplete
PR_EMS_AB_X121_ADDRESS: Incomplete
PR_EMS_AB_X121_ADDRESS_A: Incomplete
PR_EMS_AB_X121_ADDRESS_W: Incomplete
PR_EMS_AB_X25_CALL_USER_DATA_INCOMING: Incomplete
PR_EMS_AB_X25_CALL_USER_DATA_OUTGOING: Incomplete
PR_EMS_AB_X25_FACILITIES_DATA_INCOMING: Incomplete
PR_EMS_AB_X25_FACILITIES_DATA_OUTGOING: Incomplete
PR_EMS_AB_X25_LEASED_LINE_PORT: Incomplete
PR_EMS_AB_X25_LEASED_OR_SWITCHED: Incomplete
PR_EMS_AB_X25_REMOTE_MTA_PHONE: Incomplete
PR_EMS_AB_X25_REMOTE_MTA_PHONE_A: Incomplete
PR_EMS_AB_X25_REMOTE_MTA_PHONE_W: Incomplete
PR_EMS_AB_X400_ATTACHMENT_TYPE: Incomplete
PR_EMS_AB_X400_SELECTOR_SYNTAX: Incomplete
PR_EMS_AB_X500_ACCESS_CONTROL_LIST: Incomplete
PR_EMS_AB_XMIT_TIMEOUT_NON_URGENT: Incomplete
PR_EMS_AB_XMIT_TIMEOUT_NORMAL: Incomplete
PR_EMS_AB_XMIT_TIMEOUT_URGENT: Incomplete



from _typeshed import Incomplete

def CoInitializeEx() -> None: ...
def CoUninitialize() -> None: ...
def RegisterServiceCtrlHandler(serviceName: str, callback, extra_args: bool = ...): ...
def LogMsg(__errorType: int, __eventId: int, __inserts: tuple[str, str] | None = ...) -> None: ...
def LogInfoMsg(msg: str) -> None: ...
def LogErrorMsg(msg: str) -> None: ...
def LogWarningMsg(msg: str) -> None: ...
def PumpWaitingMessages(__firstMessage: int = ..., __lastMessage: int = ...) -> int: ...
def Debugging(newVal: int = ...): ...
def Initialize(eventSourceName: str | None = ..., eventSourceFile: str | None = ...) -> None: ...
def Finalize() -> None: ...
def PrepareToHostSingle(klass: Incomplete | None = ...) -> None: ...
def PrepareToHostMultiple(service_name: str, klass) -> None: ...
def RunningAsService(): ...
def SetEventSourceName(sourceName: str, registerNow: bool = ...) -> None: ...
def StartServiceCtrlDispatcher(*args, **kwargs): ...  # incomplete

COINIT_APARTMENTTHREADED: int
COINIT_DISABLE_OLE1DDE: int
COINIT_MULTITHREADED: int
COINIT_SPEED_OVER_MEMORY: int
EVENTLOG_AUDIT_FAILURE: int
EVENTLOG_AUDIT_SUCCESS: int
EVENTLOG_ERROR_TYPE: int
EVENTLOG_INFORMATION_TYPE: int
EVENTLOG_WARNING_TYPE: int
PYS_SERVICE_STARTED: int
PYS_SERVICE_STARTING: int
PYS_SERVICE_STOPPED: int
PYS_SERVICE_STOPPING: int

class startup_error(Exception): ...



from _typeshed import Incomplete

from win32com.axdebug import contexts as contexts, documents, gateways as gateways
from win32com.axdebug.util import trace as trace
from win32com.axscript import axscript as axscript

currentDebugger: Incomplete

class ModuleTreeNode:
    moduleName: Incomplete
    module: Incomplete
    realNode: Incomplete
    cont: Incomplete
    def __init__(self, module) -> None: ...
    def Attach(self, parentRealNode) -> None: ...
    def Close(self) -> None: ...

def BuildModule(module, built_nodes, rootNode, create_node_fn, create_node_args) -> None: ...
def RefreshAllModules(builtItems, rootNode, create_node, create_node_args) -> None: ...

class CodeContainerProvider(documents.CodeContainerProvider):
    axdebugger: Incomplete
    currentNumModules: Incomplete
    nodes: Incomplete
    def __init__(self, axdebugger) -> None: ...
    def FromFileName(self, fname): ...
    def Close(self) -> None: ...

class OriginalInterfaceMaker:
    cookie: Incomplete
    def MakeInterfaces(self, pdm): ...
    def CloseInterfaces(self, pdm) -> None: ...

class SimpleHostStyleInterfaceMaker:
    def MakeInterfaces(self, pdm): ...
    def CloseInterfaces(self, pdm) -> None: ...

class AXDebugger:
    pydebugger: Incomplete
    pdm: Incomplete
    interfaceMaker: Incomplete
    expressionCookie: Incomplete
    def __init__(self, interfaceMaker: Incomplete | None = ..., processName: Incomplete | None = ...) -> None: ...
    def Break(self) -> None: ...
    app: Incomplete
    root: Incomplete
    def Close(self) -> None: ...
    def RefreshAllModules(self, nodes, containerProvider) -> None: ...
    def CreateApplicationNode(self, node, containerProvider): ...

def Break() -> None: ...

brk = Break
set_trace = Break

def dosomethingelse() -> None: ...
def dosomething() -> None: ...
def test() -> None: ...



from _typeshed import Incomplete, ReadableBuffer
from array import array
from typing import NamedTuple

is64bit: bool

class _WMNOTIFY(NamedTuple):
    hwndFrom: Incomplete
    idFrom: Incomplete
    code: Incomplete

def UnpackWMNOTIFY(lparam: int) -> _WMNOTIFY: ...

class _NMITEMACTIVATE(NamedTuple):
    hwndFrom: Incomplete
    idFrom: Incomplete
    code: Incomplete
    iItem: Incomplete
    iSubItem: Incomplete
    uNewState: Incomplete
    uOldState: Incomplete
    uChanged: Incomplete
    actionx: Incomplete
    actiony: Incomplete
    lParam: Incomplete

def UnpackNMITEMACTIVATE(lparam) -> _NMITEMACTIVATE: ...
def PackMENUITEMINFO(
    fType: Incomplete | None = ...,
    fState: Incomplete | None = ...,
    wID: Incomplete | None = ...,
    hSubMenu: Incomplete | None = ...,
    hbmpChecked: Incomplete | None = ...,
    hbmpUnchecked: Incomplete | None = ...,
    dwItemData: Incomplete | None = ...,
    text: Incomplete | None = ...,
    hbmpItem: Incomplete | None = ...,
    dwTypeData: Incomplete | None = ...,
) -> tuple[array[int], list[Incomplete]]: ...

class _MENUITEMINFO(NamedTuple):
    fType: int | None
    fState: int | None
    wID: int | None
    hSubMenu: int | None
    hbmpChecked: int | None
    hbmpUnchecked: int | None
    dwItemData: int | None
    text: str | None
    hbmpItem: int | None

def UnpackMENUITEMINFO(s: ReadableBuffer) -> _MENUITEMINFO: ...
def EmptyMENUITEMINFO(mask: Incomplete | None = ..., text_buf_size: int = ...) -> tuple[array[int], list[array[int]]]: ...
def PackMENUINFO(
    dwStyle: Incomplete | None = ...,
    cyMax: Incomplete | None = ...,
    hbrBack: Incomplete | None = ...,
    dwContextHelpID: Incomplete | None = ...,
    dwMenuData: Incomplete | None = ...,
    fMask: int = ...,
) -> array[int]: ...

class _MENUINFO(NamedTuple):
    dwStyle: Incomplete | None
    cyMax: Incomplete | None
    hbrBack: Incomplete | None
    dwContextHelpID: Incomplete | None
    dwMenuData: Incomplete | None

def UnpackMENUINFO(s: ReadableBuffer) -> _MENUINFO: ...
def EmptyMENUINFO(mask: Incomplete | None = ...) -> array[int]: ...
def PackTVINSERTSTRUCT(parent, insertAfter, tvitem) -> tuple[bytes, list[Incomplete]]: ...
def PackTVITEM(hitem, state, stateMask, text, image, selimage, citems, param) -> tuple[array[int], list[Incomplete]]: ...
def EmptyTVITEM(hitem, mask: Incomplete | None = ..., text_buf_size: int = ...) -> tuple[array[int], list[Incomplete]]: ...

class _TVITEM(NamedTuple):
    item_hItem: Incomplete
    item_state: Incomplete | None
    item_stateMask: Incomplete | None
    text: Incomplete | None
    item_image: Incomplete | None
    item_selimage: Incomplete | None
    item_cChildren: Incomplete | None
    item_param: Incomplete | None

def UnpackTVITEM(buffer: ReadableBuffer) -> _TVITEM: ...

class _TVNOTIFY(NamedTuple):
    hwndFrom: Incomplete
    id: Incomplete
    code: Incomplete
    action: Incomplete
    item_old: _TVITEM
    item_new: _TVITEM

def UnpackTVNOTIFY(lparam: int) -> _TVNOTIFY: ...

class _TVDISPINFO(NamedTuple):
    hwndFrom: Incomplete
    id: Incomplete
    code: Incomplete
    item: _TVITEM

def UnpackTVDISPINFO(lparam: int) -> _TVDISPINFO: ...
def PackLVITEM(
    item: Incomplete | None = ...,
    subItem: Incomplete | None = ...,
    state: Incomplete | None = ...,
    stateMask: Incomplete | None = ...,
    text: Incomplete | None = ...,
    image: Incomplete | None = ...,
    param: Incomplete | None = ...,
    indent: Incomplete | None = ...,
) -> tuple[array[int], list[Incomplete]]: ...

class _LVITEM(NamedTuple):
    item_item: Incomplete
    item_subItem: Incomplete
    item_state: Incomplete | None
    item_stateMask: Incomplete | None
    text: Incomplete | None
    item_image: Incomplete | None
    item_param: Incomplete | None
    item_indent: Incomplete | None

def UnpackLVITEM(buffer: ReadableBuffer) -> _LVITEM: ...

class _LVDISPINFO(NamedTuple):
    hwndFrom: Incomplete
    id: Incomplete
    code: Incomplete
    item: _LVITEM

def UnpackLVDISPINFO(lparam: int) -> _LVDISPINFO: ...

class _UnpackLVNOTIFY(NamedTuple):
    hwndFrom: Incomplete
    id: Incomplete
    code: Incomplete
    item: Incomplete
    subitem: Incomplete
    newstate: Incomplete
    oldstate: Incomplete
    changed: Incomplete
    pt: tuple[Incomplete, Incomplete]
    lparam: Incomplete

def UnpackLVNOTIFY(lparam: int) -> _UnpackLVNOTIFY: ...
def EmptyLVITEM(
    item, subitem, mask: Incomplete | None = ..., text_buf_size: int = ...
) -> tuple[array[int], list[Incomplete]]: ...
def PackLVCOLUMN(
    fmt: Incomplete | None = ...,
    cx: Incomplete | None = ...,
    text: Incomplete | None = ...,
    subItem: Incomplete | None = ...,
    image: Incomplete | None = ...,
    order: Incomplete | None = ...,
) -> tuple[array[int], list[Incomplete]]: ...

class _LVCOLUMN(NamedTuple):
    fmt: Incomplete | None
    cx: Incomplete | None
    text: Incomplete | None
    subItem: Incomplete | None
    image: Incomplete | None
    order: Incomplete | None

def UnpackLVCOLUMN(lparam: ReadableBuffer) -> _LVCOLUMN: ...
def EmptyLVCOLUMN(mask: Incomplete | None = ..., text_buf_size: int = ...) -> tuple[array[int], list[Incomplete]]: ...
def PackLVHITTEST(pt) -> tuple[array[int], None]: ...

class _LVHITTEST(NamedTuple):
    pt: tuple[Incomplete, Incomplete]
    flags: Incomplete
    item: Incomplete
    subitem: Incomplete

def UnpackLVHITTEST(buf: ReadableBuffer) -> tuple[tuple[Incomplete, Incomplete], Incomplete, Incomplete, Incomplete]: ...
def PackHDITEM(
    cxy: Incomplete | None = ...,
    text: Incomplete | None = ...,
    hbm: Incomplete | None = ...,
    fmt: Incomplete | None = ...,
    param: Incomplete | None = ...,
    image: Incomplete | None = ...,
    order: Incomplete | None = ...,
) -> tuple[array[int], list[Incomplete]]: ...
def PackDEV_BROADCAST(devicetype, rest_fmt, rest_data, extra_data=...) -> bytes: ...
def PackDEV_BROADCAST_HANDLE(handle, hdevnotify: int = ..., guid=..., name_offset: int = ..., data=...) -> bytes: ...
def PackDEV_BROADCAST_VOLUME(unitmask, flags) -> bytes: ...
def PackDEV_BROADCAST_DEVICEINTERFACE(classguid, name: str = ...) -> bytes: ...

class DEV_BROADCAST_INFO:
    devicetype: Incomplete
    def __init__(self, devicetype, **kw) -> None: ...

def UnpackDEV_BROADCAST(lparam: int) -> DEV_BROADCAST_INFO | None: ...



import _win32typing

CLSID_CTask: _win32typing.PyIID
CLSID_CTaskScheduler: _win32typing.PyIID
HIGH_PRIORITY_CLASS: int
IDLE_PRIORITY_CLASS: int
IID_IProvideTaskPage: _win32typing.PyIID
IID_IScheduledWorkItem: _win32typing.PyIID
IID_ITask: _win32typing.PyIID
IID_ITaskScheduler: _win32typing.PyIID
IID_ITaskTrigger: _win32typing.PyIID
NORMAL_PRIORITY_CLASS: int
REALTIME_PRIORITY_CLASS: int
SCHED_E_ACCOUNT_DBASE_CORRUPT: int
SCHED_E_ACCOUNT_INFORMATION_NOT_SET: int
SCHED_E_ACCOUNT_NAME_NOT_FOUND: int
SCHED_E_CANNOT_OPEN_TASK: int
SCHED_E_INVALID_TASK: int
SCHED_E_SERVICE_NOT_INSTALLED: int
SCHED_E_TASK_NOT_READY: int
SCHED_E_TASK_NOT_RUNNING: int
SCHED_E_TRIGGER_NOT_FOUND: int
SCHED_E_UNKNOWN_OBJECT_VERSION: int
SCHED_S_EVENT_TRIGGER: int
SCHED_S_TASK_DISABLED: int
SCHED_S_TASK_HAS_NOT_RUN: int
SCHED_S_TASK_NOT_SCHEDULED: int
SCHED_S_TASK_NO_MORE_RUNS: int
SCHED_S_TASK_NO_VALID_TRIGGERS: int
SCHED_S_TASK_READY: int
SCHED_S_TASK_RUNNING: int
SCHED_S_TASK_TERMINATED: int
TASKPAGE_SCHEDULE: int
TASKPAGE_SETTINGS: int
TASKPAGE_TASK: int
TASK_APRIL: int
TASK_AUGUST: int
TASK_DECEMBER: int
TASK_EVENT_TRIGGER_AT_LOGON: int
TASK_EVENT_TRIGGER_AT_SYSTEMSTART: int
TASK_EVENT_TRIGGER_ON_IDLE: int
TASK_FEBRUARY: int
TASK_FIRST_WEEK: int
TASK_FLAG_DELETE_WHEN_DONE: int
TASK_FLAG_DISABLED: int
TASK_FLAG_DONT_START_IF_ON_BATTERIES: int
TASK_FLAG_HIDDEN: int
TASK_FLAG_INTERACTIVE: int
TASK_FLAG_KILL_IF_GOING_ON_BATTERIES: int
TASK_FLAG_KILL_ON_IDLE_END: int
TASK_FLAG_RESTART_ON_IDLE_RESUME: int
TASK_FLAG_RUN_IF_CONNECTED_TO_INTERNET: int
TASK_FLAG_RUN_ONLY_IF_DOCKED: int
TASK_FLAG_RUN_ONLY_IF_LOGGED_ON: int
TASK_FLAG_START_ONLY_IF_IDLE: int
TASK_FLAG_SYSTEM_REQUIRED: int
TASK_FOURTH_WEEK: int
TASK_FRIDAY: int
TASK_JANUARY: int
TASK_JULY: int
TASK_JUNE: int
TASK_LAST_WEEK: int
TASK_MARCH: int
TASK_MAY: int
TASK_MONDAY: int
TASK_NOVEMBER: int
TASK_OCTOBER: int
TASK_SATURDAY: int
TASK_SECOND_WEEK: int
TASK_SEPTEMBER: int
TASK_SUNDAY: int
TASK_THIRD_WEEK: int
TASK_THURSDAY: int
TASK_TIME_TRIGGER_DAILY: int
TASK_TIME_TRIGGER_MONTHLYDATE: int
TASK_TIME_TRIGGER_MONTHLYDOW: int
TASK_TIME_TRIGGER_ONCE: int
TASK_TIME_TRIGGER_WEEKLY: int
TASK_TRIGGER_FLAG_DISABLED: int
TASK_TRIGGER_FLAG_HAS_END_DATE: int
TASK_TRIGGER_FLAG_KILL_AT_DURATION_END: int
TASK_TUESDAY: int
TASK_WEDNESDAY: int



from _typeshed import Incomplete

def WTSOpenServer(ServerName: str) -> int: ...
def WTSCloseServer(Server: int) -> None: ...
def WTSQueryUserConfig(ServerName: str, UserName: str, ConfigClass): ...
def WTSSetUserConfig(ServerName: str, UserName: str, ConfigClass) -> None: ...
def WTSEnumerateServers(DomainName: str | None = ..., Version: int = ..., Reserved=...) -> tuple[str, ...]: ...
def WTSEnumerateSessions(__Server: int, __Version: int = ..., __Reserved=...) -> tuple[dict[str, str | int], ...]: ...
def WTSLogoffSession(__Server: int, __SessionId: int, __Wait: bool) -> None: ...
def WTSDisconnectSession(__Server: int, __SessionId: int, __Wait: bool) -> None: ...
def WTSQuerySessionInformation(__Server: int, __SessionId: int, __WTSInfoClass: int) -> str: ...
def WTSEnumerateProcesses(Server: int, Version: int = ..., Reserved: int = ...) -> tuple[str, ...]: ...
def WTSQueryUserToken(SessionId) -> int: ...
def WTSShutdownSystem(Server: int, ShutdownFlag) -> None: ...
def WTSTerminateProcess(Server: int, ProcessId, ExitCode) -> None: ...
def ProcessIdToSessionId(ProcessId): ...
def WTSGetActiveConsoleSessionId(): ...
def WTSRegisterSessionNotification(Wnd: int, Flags) -> None: ...
def WTSUnRegisterSessionNotification(Wnd: int) -> None: ...
def WTSWaitSystemEvent(Server: int, EventMask): ...
def WTSSendMessage(Server: int, SessionId, Title: str, Message: str, Style, Timeout, Wait): ...

NOTIFY_FOR_ALL_SESSIONS: int
NOTIFY_FOR_THIS_SESSION: int
WTSActive: int
WTSApplicationName: int
WTSClientAddress: int
WTSClientBuildNumber: int
WTSClientDirectory: int
WTSClientDisplay: int
WTSClientHardwareId: int
WTSClientName: int
WTSClientProductId: int
WTSClientProtocolType: int
WTSConnectQuery: int
WTSConnectState: int
WTSConnected: int
WTSDisconnected: int
WTSDomainName: int
WTSDown: int
WTSIdle: int
WTSInit: int
WTSInitialProgram: int
WTSListen: int
WTSOEMId: int
WTSReset: int
WTSSessionId: int
WTSShadow: int
WTSUserConfigBrokenTimeoutSettings: int
WTSUserConfigInitialProgram: int
WTSUserConfigModemCallbackPhoneNumber: int
WTSUserConfigModemCallbackSettings: int
WTSUserConfigReconnectSettings: int
WTSUserConfigShadowingSettings: int
WTSUserConfigTerminalServerHomeDir: int
WTSUserConfigTerminalServerHomeDirDrive: int
WTSUserConfigTerminalServerProfilePath: int
WTSUserConfigTimeoutSettingsConnections: int
WTSUserConfigTimeoutSettingsDisconnections: int
WTSUserConfigTimeoutSettingsIdle: int
WTSUserConfigWorkingDirectory: int
WTSUserConfigfAllowLogonTerminalServer: int
WTSUserConfigfDeviceClientDefaultPrinter: int
WTSUserConfigfDeviceClientDrives: int
WTSUserConfigfDeviceClientPrinters: int
WTSUserConfigfInheritInitialProgram: int
WTSUserConfigfTerminalServerRemoteHomeDir: int
WTSUserName: int
WTSVirtualClientData: int
WTSVirtualFileHandle: int
WTSWinStationName: int
WTSWorkingDirectory: int
WTS_CURRENT_SERVER: int
WTS_CURRENT_SERVER_HANDLE: int
WTS_CURRENT_SERVER_NAME: Incomplete
WTS_CURRENT_SESSION: int
WTS_EVENT_ALL: int
WTS_EVENT_CONNECT: int
WTS_EVENT_CREATE: int
WTS_EVENT_DELETE: int
WTS_EVENT_DISCONNECT: int
WTS_EVENT_FLUSH: int
WTS_EVENT_LICENSE: int
WTS_EVENT_LOGOFF: int
WTS_EVENT_LOGON: int
WTS_EVENT_NONE: int
WTS_EVENT_RENAME: int
WTS_EVENT_STATECHANGE: int
WTS_PROTOCOL_TYPE_CONSOLE: int
WTS_PROTOCOL_TYPE_ICA: int
WTS_PROTOCOL_TYPE_RDP: int
WTS_WSD_FASTREBOOT: int
WTS_WSD_LOGOFF: int
WTS_WSD_POWEROFF: int
WTS_WSD_REBOOT: int
WTS_WSD_SHUTDOWN: int



import _win32typing
from win32.lib.pywintypes import error as error

def mmapfile(
    File, Name, MaximumSize: int = ..., FileOffset: int = ..., NumberOfBytesToMap: int = ...
) -> _win32typing.Pymmapfile: ...



STGC_DEFAULT: int
STGC_OVERWRITE: int
STGC_ONLYIFCURRENT: int
STGC_DANGEROUSLYCOMMITMERELYTODISKCACHE: int
STGC_CONSOLIDATE: int
STGTY_STORAGE: int
STGTY_STREAM: int
STGTY_LOCKBYTES: int
STGTY_PROPERTY: int
STREAM_SEEK_SET: int
STREAM_SEEK_CUR: int
STREAM_SEEK_END: int
LOCK_WRITE: int
LOCK_EXCLUSIVE: int
LOCK_ONLYONCE: int
CWCSTORAGENAME: int
STGM_DIRECT: int
STGM_TRANSACTED: int
STGM_SIMPLE: int
STGM_READ: int
STGM_WRITE: int
STGM_READWRITE: int
STGM_SHARE_DENY_NONE: int
STGM_SHARE_DENY_READ: int
STGM_SHARE_DENY_WRITE: int
STGM_SHARE_EXCLUSIVE: int
STGM_PRIORITY: int
STGM_DELETEONRELEASE: int
STGM_NOSCRATCH: int
STGM_CREATE: int
STGM_CONVERT: int
STGM_FAILIFTHERE: int
STGM_NOSNAPSHOT: int
ASYNC_MODE_COMPATIBILITY: int
ASYNC_MODE_DEFAULT: int
STGTY_REPEAT: int
STG_TOEND: int
STG_LAYOUT_SEQUENTIAL: int
STG_LAYOUT_INTERLEAVED: int
COM_RIGHTS_EXECUTE: int
COM_RIGHTS_EXECUTE_LOCAL: int
COM_RIGHTS_EXECUTE_REMOTE: int
COM_RIGHTS_ACTIVATE_LOCAL: int
COM_RIGHTS_ACTIVATE_REMOTE: int
STGFMT_DOCUMENT: int
STGFMT_STORAGE: int
STGFMT_NATIVE: int
STGFMT_FILE: int
STGFMT_ANY: int
STGFMT_DOCFILE: int
PID_DICTIONARY: int
PID_CODEPAGE: int
PID_FIRST_USABLE: int
PID_FIRST_NAME_DEFAULT: int
PID_LOCALE: int
PID_MODIFY_TIME: int
PID_SECURITY: int
PID_BEHAVIOR: int
PID_ILLEGAL: int
PID_MIN_READONLY: int
PID_MAX_READONLY: int
PIDDI_THUMBNAIL: int
PIDSI_TITLE: int
PIDSI_SUBJECT: int
PIDSI_AUTHOR: int
PIDSI_KEYWORDS: int
PIDSI_COMMENTS: int
PIDSI_TEMPLATE: int
PIDSI_LASTAUTHOR: int
PIDSI_REVNUMBER: int
PIDSI_EDITTIME: int
PIDSI_LASTPRINTED: int
PIDSI_CREATE_DTM: int
PIDSI_LASTSAVE_DTM: int
PIDSI_PAGECOUNT: int
PIDSI_WORDCOUNT: int
PIDSI_CHARCOUNT: int
PIDSI_THUMBNAIL: int
PIDSI_APPNAME: int
PIDSI_DOC_SECURITY: int
PIDDSI_CATEGORY: int
PIDDSI_PRESFORMAT: int
PIDDSI_BYTECOUNT: int
PIDDSI_LINECOUNT: int
PIDDSI_PARCOUNT: int
PIDDSI_SLIDECOUNT: int
PIDDSI_NOTECOUNT: int
PIDDSI_HIDDENCOUNT: int
PIDDSI_MMCLIPCOUNT: int
PIDDSI_SCALE: int
PIDDSI_HEADINGPAIR: int
PIDDSI_DOCPARTS: int
PIDDSI_MANAGER: int
PIDDSI_COMPANY: int
PIDDSI_LINKSDIRTY: int
PIDMSI_EDITOR: int
PIDMSI_SUPPLIER: int
PIDMSI_SOURCE: int
PIDMSI_SEQUENCE_NO: int
PIDMSI_PROJECT: int
PIDMSI_STATUS: int
PIDMSI_OWNER: int
PIDMSI_RATING: int
PIDMSI_PRODUCTION: int
PIDMSI_COPYRIGHT: int
PROPSETFLAG_DEFAULT: int
PROPSETFLAG_NONSIMPLE: int
PROPSETFLAG_ANSI: int
PROPSETFLAG_UNBUFFERED: int
PROPSETFLAG_CASE_SENSITIVE: int
STGMOVE_MOVE: int
STGMOVE_COPY: int
STGMOVE_SHALLOWCOPY: int
